package lotus.notes;

import java.util.Enumeration;
import java.util.Vector;

public class Database extends NotesBase {
   private transient Session session;
   private transient Vector doclist;
   private transient Vector viewlist;
   private transient Vector objlist;
   public static final int ACLLEVEL_NOACCESS = 0;
   public static final int ACLLEVEL_DEPOSITOR = 1;
   public static final int ACLLEVEL_READER = 2;
   public static final int ACLLEVEL_AUTHOR = 3;
   public static final int ACLLEVEL_EDITOR = 4;
   public static final int ACLLEVEL_DESIGNER = 5;
   public static final int ACLLEVEL_MANAGER = 6;
   public static final int FT_SCORES = 8;
   public static final int FT_DATE_DES = 32;
   public static final int FT_DATE_ASC = 64;
   public static final int FT_STEMS = 512;
   public static final int FT_THESAURUS = 1024;

   private native int Ncompact();

   private native int NcreateDocument();

   private native int NcreateCopy(String var1, String var2, int var3);

   private native int NcreateFromTemplate(String var1, String var2, boolean var3, int var4);

   private native int NcreateReplica(String var1, String var2);

   private native int NgetDocumentByID(String var1);

   private native int NgetDocumentByUNID(String var1);

   private native int NgetDocumentByURL(String var1, boolean var2, boolean var3, boolean var4, String var5, String var6, String var7, String var8, String var9, boolean var10);

   private native String NgetURLHeaderInfo(String var1, String var2, String var3, String var4, String var5, String var6);

   private native int NgetView(String var1);

   private native void NgrantAccess(String var1, int var2);

   private native int NqueryAccess(String var1);

   private native void Nremove();

   private native boolean Nreplicate(String var1);

   private native void NrevokeAccess(String var1);

   private native void NupdateFTIndex(boolean var1);

   private native int NFTSearch(String var1, int var2, int var3, int var4);

   private native int Nsearch(String var1, DateTime var2, int var3);

   private native int NgetProfileDocument(String var1, String var2);

   private native int NgetAgent(String var1);

   private native int NgetForm(String var1);

   private native boolean Nopen();

   protected Database() throws NotesException {
   }

   protected Database(Session var1, int var2) throws NotesException {
      super(var2, 2);
      if (var1 == null) {
         throw new NotesException(JavaString.resource.getString("missing_session_object"));
      } else {
         this.session = var1;
         this.doclist = new Vector(3);
         this.viewlist = new Vector(3);
         this.objlist = new Vector(3);
         var1.AddDatabase(this);
      }
   }

   protected void InternalFinalize() throws NotesException {
      try {
         Vector var7 = this.doclist;
         synchronized(var7){}

         try {
            Enumeration var4 = this.doclist.elements();

            while(var4.hasMoreElements()) {
               Object var1 = var4.nextElement();
               super.DestroyObject((NotesBase)var1);
            }
         } catch (Throwable var114) {
            throw var114;
         }

         var7 = this.viewlist;
         synchronized(var7){}

         try {
            Enumeration var117 = this.viewlist.elements();

            while(var117.hasMoreElements()) {
               Object var2 = var117.nextElement();
               super.DestroyObject((NotesBase)var2);
            }
         } catch (Throwable var113) {
            throw var113;
         }

         var7 = this.objlist;
         synchronized(var7){}

         try {
            Enumeration var118 = this.objlist.elements();

            while(var118.hasMoreElements()) {
               Object var3 = var118.nextElement();
               super.DestroyObject((NotesBase)var3);
            }
         } catch (Throwable var112) {
            throw var112;
         }
      } catch (Exception var115) {
      } finally {
         if (this.doclist != null) {
            Vector var121 = this.doclist;
            synchronized(var121){}

            try {
               this.doclist.removeAllElements();
               this.doclist = null;
            } catch (Throwable var111) {
               throw var111;
            }
         }

         if (this.viewlist != null) {
            Vector var122 = this.viewlist;
            synchronized(var122){}

            try {
               this.viewlist.removeAllElements();
               this.viewlist = null;
            } catch (Throwable var110) {
               throw var110;
            }
         }

         if (this.objlist != null) {
            Vector var123 = this.objlist;
            synchronized(var123){}

            try {
               this.objlist.removeAllElements();
               this.objlist = null;
            } catch (Throwable var109) {
               throw var109;
            }
         }

         super.finalize();
      }

   }

   public void finalize() throws NotesException {
      this.session.RemoveDatabase(this);
      this.InternalFinalize();
   }

   protected void AddDocument(Object var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      Vector var2 = this.doclist;
      synchronized(var2){}

      try {
         this.doclist.addElement(var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   protected void RemoveDocument(Object var1) throws NotesException {
      if (this.doclist != null) {
         Vector var2 = this.doclist;
         synchronized(var2){}

         try {
            this.doclist.removeElement(var1);
         } catch (Throwable var4) {
            throw var4;
         }

      }
   }

   protected void AddView(Object var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      Vector var2 = this.viewlist;
      synchronized(var2){}

      try {
         this.viewlist.addElement(var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   protected void RemoveView(Object var1) throws NotesException {
      if (this.viewlist != null) {
         Vector var2 = this.viewlist;
         synchronized(var2){}

         try {
            this.viewlist.removeElement(var1);
         } catch (Throwable var4) {
            throw var4;
         }

      }
   }

   protected void AddObject(Object var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      Vector var2 = this.objlist;
      synchronized(var2){}

      try {
         this.objlist.addElement(var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   protected void RemoveObject(Object var1) throws NotesException {
      if (this.objlist != null) {
         Vector var2 = this.objlist;
         synchronized(var2){}

         try {
            this.objlist.removeElement(var1);
         } catch (Throwable var4) {
            throw var4;
         }

      }
   }

   protected Document FindOrCreateDocument(int var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      if (var1 == 0) {
         return null;
      } else {
         Vector var4 = this.doclist;
         synchronized(var4){}

         Document var3;
         try {
            Enumeration var6 = this.doclist.elements();

            Document var2;
            do {
               if (!var6.hasMoreElements()) {
                  return new Document(this, var1);
               }

               var2 = (Document)var6.nextElement();
            } while(!((NotesBase)var2).isEqual(var1));

            var3 = var2;
         } catch (Throwable var8) {
            throw var8;
         }

         return var3;
      }
   }

   protected View FindOrCreateView(int var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      if (var1 == 0) {
         return null;
      } else {
         Vector var4 = this.viewlist;
         synchronized(var4){}

         View var3;
         try {
            Enumeration var6 = this.viewlist.elements();

            View var2;
            do {
               if (!var6.hasMoreElements()) {
                  return new View(this, var1);
               }

               var2 = (View)var6.nextElement();
            } while(!((NotesBase)var2).isEqual(var1));

            var3 = var2;
         } catch (Throwable var8) {
            throw var8;
         }

         return var3;
      }
   }

   protected Agent FindOrCreateAgent(int var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      if (var1 == 0) {
         return null;
      } else {
         Vector var4 = this.objlist;
         synchronized(var4){}

         Agent var3;
         try {
            Enumeration var6 = this.objlist.elements();

            NotesBase var2;
            do {
               if (!var6.hasMoreElements()) {
                  return new Agent(this, var1);
               }

               var2 = (NotesBase)var6.nextElement();
            } while(!(var2 instanceof Agent) || !var2.isEqual(var1));

            var3 = (Agent)var2;
         } catch (Throwable var8) {
            throw var8;
         }

         return var3;
      }
   }

   protected Form FindOrCreateForm(int var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      if (var1 == 0) {
         return null;
      } else {
         Vector var4 = this.objlist;
         synchronized(var4){}

         Form var3;
         try {
            Enumeration var6 = this.objlist.elements();

            NotesBase var2;
            do {
               if (!var6.hasMoreElements()) {
                  return new Form(this, var1);
               }

               var2 = (NotesBase)var6.nextElement();
            } while(!(var2 instanceof Form) || !var2.isEqual(var1));

            var3 = (Form)var2;
         } catch (Throwable var8) {
            throw var8;
         }

         return var3;
      }
   }

   protected DocumentCollection FindOrCreateDocCollection(int var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      if (var1 == 0) {
         return null;
      } else {
         Vector var4 = this.objlist;
         synchronized(var4){}

         DocumentCollection var3;
         try {
            Enumeration var6 = this.objlist.elements();

            NotesBase var2;
            do {
               if (!var6.hasMoreElements()) {
                  return new DocumentCollection(this, var1);
               }

               var2 = (NotesBase)var6.nextElement();
            } while(!(var2 instanceof DocumentCollection) || !var2.isEqual(var1));

            var3 = (DocumentCollection)var2;
         } catch (Throwable var8) {
            throw var8;
         }

         return var3;
      }
   }

   protected ACL FindOrCreateACL(int var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      if (var1 == 0) {
         return null;
      } else {
         Vector var4 = this.objlist;
         synchronized(var4){}

         ACL var3;
         try {
            Enumeration var6 = this.objlist.elements();

            NotesBase var2;
            do {
               if (!var6.hasMoreElements()) {
                  return new ACL(this, var1);
               }

               var2 = (NotesBase)var6.nextElement();
            } while(!(var2 instanceof ACL) || !var2.isEqual(var1));

            var3 = (ACL)var2;
         } catch (Throwable var8) {
            throw var8;
         }

         return var3;
      }
   }

   public void recycle() throws NotesException {
      boolean var6 = false;

      try {
         AgentContext var9 = this.session.getAgentContext();
         if (var9 != null) {
            Database var5 = var9.getCurrentDatabase();
            if (this.GetCppObj() == var5.GetCppObj()) {
               var6 = true;
            }
         }

         if (!var6) {
            this.session.RemoveDatabase(this);
            Vector var10 = this.doclist;
            synchronized(var10){}

            try {
               Enumeration var4 = this.doclist.elements();

               while(var4.hasMoreElements()) {
                  Object var1 = var4.nextElement();
                  super.RecycleObject((NotesBase)var1);
               }
            } catch (Throwable var117) {
               throw var117;
            }

            var10 = this.viewlist;
            synchronized(var10){}

            try {
               Enumeration var120 = this.viewlist.elements();

               while(var120.hasMoreElements()) {
                  Object var2 = var120.nextElement();
                  super.RecycleObject((NotesBase)var2);
               }
            } catch (Throwable var116) {
               throw var116;
            }

            var10 = this.objlist;
            synchronized(var10){}

            try {
               Enumeration var121 = this.objlist.elements();

               while(var121.hasMoreElements()) {
                  Object var3 = var121.nextElement();
                  super.RecycleObject((NotesBase)var3);
               }
            } catch (Throwable var115) {
               throw var115;
            }
         }
      } catch (NotesException var118) {
      } finally {
         if (!var6) {
            if (this.doclist != null) {
               Vector var122 = this.doclist;
               synchronized(var122){}

               try {
                  this.doclist.removeAllElements();
                  this.doclist = null;
               } catch (Throwable var114) {
                  throw var114;
               }
            }

            if (this.viewlist != null) {
               Vector var123 = this.viewlist;
               synchronized(var123){}

               try {
                  this.viewlist.removeAllElements();
                  this.viewlist = null;
               } catch (Throwable var113) {
                  throw var113;
               }
            }

            if (this.objlist != null) {
               Vector var124 = this.objlist;
               synchronized(var124){}

               try {
                  this.objlist.removeAllElements();
                  this.objlist = null;
               } catch (Throwable var112) {
                  throw var112;
               }
            }

            super.Recycle();
         }

      }

   }

   public int GetCppObj() {
      return super.GetCppObj();
   }

   public boolean open() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = this.Nopen();
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public int compact() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      int var1;
      try {
         var1 = this.Ncompact();
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public Database createCopy(String var1, String var2, int var3) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Database var4;
      try {
         var4 = this.session.FindOrCreateDatabase(this.NcreateCopy(var1, var2, var3));
      } catch (Throwable var8) {
         throw var8;
      }

      return var4;
   }

   public Database createCopy(String var1, String var2) throws NotesException {
      return this.createCopy(var1, var2, 0);
   }

   public Document createDocument() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var1;
      try {
         int var4 = this.NcreateDocument();
         var1 = this.FindOrCreateDocument(var4);
      } catch (Throwable var6) {
         throw var6;
      }

      return var1;
   }

   public Database createFromTemplate(String var1, String var2, boolean var3, int var4) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Database var5;
      try {
         var5 = this.session.FindOrCreateDatabase(this.NcreateFromTemplate(var1, var2, var3, var4));
      } catch (Throwable var9) {
         throw var9;
      }

      return var5;
   }

   public Database createFromTemplate(String var1, String var2, boolean var3) throws NotesException {
      return this.createFromTemplate(var1, var2, var3, 0);
   }

   public Database createReplica(String var1, String var2) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Database var3;
      try {
         var3 = this.session.FindOrCreateDatabase(this.NcreateReplica(var1, var2));
      } catch (Throwable var7) {
         throw var7;
      }

      return var3;
   }

   public Document getDocumentByID(String var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var2;
      try {
         var2 = this.FindOrCreateDocument(this.NgetDocumentByID(var1));
      } catch (Throwable var6) {
         throw var6;
      }

      return var2;
   }

   public Document getDocumentByUNID(String var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var2;
      try {
         var2 = this.FindOrCreateDocument(this.NgetDocumentByUNID(var1));
      } catch (Throwable var6) {
         throw var6;
      }

      return var2;
   }

   public Document getDocumentByURL(String var1, boolean var2) throws NotesException {
      return this.getDocumentByURL(var1, var2, var2, false, (String)null, (String)null, (String)null, (String)null, (String)null, false);
   }

   public Document getDocumentByURL(String var1, boolean var2, boolean var3, boolean var4, String var5, String var6, String var7, String var8, String var9, boolean var10) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var11;
      try {
         var11 = this.FindOrCreateDocument(this.NgetDocumentByURL(var1, var2, var3, var4, var5, var6, var7, var8, var9, var10));
      } catch (Throwable var15) {
         throw var15;
      }

      return var11;
   }

   public String getURLHeaderInfo(String var1, String var2, String var3, String var4, String var5, String var6) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      String var7;
      try {
         var7 = this.NgetURLHeaderInfo(var1, var2, var3, var4, var5, var6);
      } catch (Throwable var11) {
         throw var11;
      }

      return var7;
   }

   public View getView(String var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      View var2;
      try {
         int var5 = this.NgetView(var1);
         var2 = this.FindOrCreateView(var5);
      } catch (Throwable var7) {
         throw var7;
      }

      return var2;
   }

   public void grantAccess(String var1, int var2) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         this.NgrantAccess(var1, var2);
      } catch (Throwable var5) {
         throw var5;
      }

   }

   public int queryAccess(String var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      int var2;
      try {
         var2 = this.NqueryAccess(var1);
      } catch (Throwable var6) {
         throw var6;
      }

      return var2;
   }

   public void remove() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         this.Nremove();
         this.session.RemoveDatabase(this);
         super.cpp_object = 0;
         this.finalize();
      } catch (Throwable var3) {
         throw var3;
      }

   }

   public boolean replicate(String var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var2;
      try {
         var2 = this.Nreplicate(var1);
      } catch (Throwable var6) {
         throw var6;
      }

      return var2;
   }

   public void revokeAccess(String var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         this.NrevokeAccess(var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   public void updateFTIndex(boolean var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         this.NupdateFTIndex(var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   public DocumentCollection FTSearch(String var1, int var2) throws NotesException {
      return this.FTSearch(var1, var2, 0, 0);
   }

   public DocumentCollection FTSearch(String var1) throws NotesException {
      return this.FTSearch(var1, 0, 0, 0);
   }

   public DocumentCollection FTSearch(String var1, int var2, int var3, int var4) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      DocumentCollection var5;
      try {
         var5 = this.FindOrCreateDocCollection(this.NFTSearch(var1, var2, var3, var4));
      } catch (Throwable var9) {
         throw var9;
      }

      return var5;
   }

   public DocumentCollection search(String var1) throws NotesException {
      return this.search(var1, (DateTime)null, 0);
   }

   public DocumentCollection search(String var1, DateTime var2) throws NotesException {
      return this.search(var1, var2, 0);
   }

   public DocumentCollection search(String var1, DateTime var2, int var3) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      DocumentCollection var4;
      try {
         var4 = this.FindOrCreateDocCollection(this.Nsearch(var1, var2, var3));
      } catch (Throwable var8) {
         throw var8;
      }

      return var4;
   }

   public Document getProfileDocument(String var1, String var2) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var3;
      try {
         var3 = this.FindOrCreateDocument(this.NgetProfileDocument(var1, var2));
      } catch (Throwable var7) {
         throw var7;
      }

      return var3;
   }

   public Agent getAgent(String var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      return this.FindOrCreateAgent(this.NgetAgent(var1));
   }

   public Form getForm(String var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      return this.FindOrCreateForm(this.NgetForm(var1));
   }

   public String getTitle() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      String var1;
      try {
         var1 = ((NotesBase)this).PropGetString(1001);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public void setTitle(String var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         ((NotesBase)this).PropSetString(1001, var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   public String getTemplateName() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      String var1;
      try {
         var1 = ((NotesBase)this).PropGetString(1003);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public String getDesignTemplateName() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      String var1;
      try {
         var1 = ((NotesBase)this).PropGetString(1004);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public String getFileName() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      String var1;
      try {
         var1 = ((NotesBase)this).PropGetString(1005);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public String getFilePath() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      String var1;
      try {
         var1 = ((NotesBase)this).PropGetString(1006);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public String toString() {
      String var1;
      try {
         var1 = this.getFilePath();
      } catch (Exception var2) {
         var1 = null;
      }

      return var1;
   }

   public String getReplicaID() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      String var1;
      try {
         var1 = ((NotesBase)this).PropGetString(1012);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public String getServer() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      String var1;
      try {
         var1 = ((NotesBase)this).PropGetString(1501);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public String getCategories() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      String var1;
      try {
         var1 = ((NotesBase)this).PropGetString(1002);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public void setCategories(String var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         ((NotesBase)this).PropSetString(1002, var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   public boolean isFTIndexed() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1000);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public boolean isOpen() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1009);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public boolean isPublicAddressBook() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1015);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public boolean isPrivateAddressBook() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1016);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public boolean isDelayUpdates() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1514);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public void setDelayUpdates(boolean var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         ((NotesBase)this).PropSetBool(1514, var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   public boolean isMultiDbSearch() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1517);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public Vector getManagers() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Vector var2;
      try {
         String[] var5 = ((NotesBase)this).PropGetStringArray(1008);
         Vector var1;
         if (var5 != null && var5.length > 0) {
            var1 = new Vector(var5.length, 1);

            for(int var6 = 0; var6 < var5.length; ++var6) {
               var1.addElement(var5[var6]);
            }
         } else {
            var1 = new Vector(1);
         }

         var2 = var1;
      } catch (Throwable var8) {
         throw var8;
      }

      return var2;
   }

   public Vector getViews() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Vector var1;
      try {
         int[] var4 = ((NotesBase)this).PropGetObjArray(1010);
         if (var4 != null && var4.length != 0) {
            Vector var7 = new Vector(var4.length);

            for(int var5 = 0; var5 < var4.length; ++var5) {
               View var6 = this.FindOrCreateView(var4[var5]);
               var7.addElement(var6);
            }

            var1 = var7;
            return var1;
         }

         var1 = null;
      } catch (Throwable var9) {
         throw var9;
      }

      return var1;
   }

   public Vector getAgents() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Vector var1;
      try {
         int[] var4 = ((NotesBase)this).PropGetObjArray(1011);
         if (var4 != null && var4.length != 0) {
            Vector var7 = new Vector(var4.length);

            for(int var6 = 0; var6 < var4.length; ++var6) {
               Agent var5 = this.FindOrCreateAgent(var4[var6]);
               var7.addElement(var5);
            }

            var1 = var7;
            return var1;
         }

         var1 = null;
      } catch (Throwable var9) {
         throw var9;
      }

      return var1;
   }

   public DocumentCollection getAllDocuments() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      DocumentCollection var1;
      try {
         int var4 = ((NotesBase)this).PropGetAdt(1047);
         var1 = this.FindOrCreateDocCollection(var4);
      } catch (Throwable var6) {
         throw var6;
      }

      return var1;
   }

   public Vector getForms() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Vector var1;
      try {
         int[] var4 = ((NotesBase)this).PropGetObjArray(1515);
         if (var4 != null && var4.length != 0) {
            Vector var7 = new Vector(var4.length);

            for(int var6 = 0; var6 < var4.length; ++var6) {
               Form var5 = this.FindOrCreateForm(var4[var6]);
               var7.addElement(var5);
            }

            var1 = var7;
            return var1;
         }

         var1 = null;
      } catch (Throwable var9) {
         throw var9;
      }

      return var1;
   }

   public Session getParent() throws NotesException {
      ((NotesBase)this).CheckObject();
      return this.session;
   }

   public int getCurrentAccessLevel() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      int var1;
      try {
         var1 = ((NotesBase)this).PropGetInt(1502);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public int getSizeQuota() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      int var1;
      try {
         var1 = ((NotesBase)this).PropGetInt(1504);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public void setSizeQuota(int var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         ((NotesBase)this).PropSetInt(1504, var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   public double getSize() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      double var1;
      try {
         var1 = ((NotesBase)this).PropGetDouble(1503);
      } catch (Throwable var6) {
         throw var6;
      }

      return var1;
   }

   public double getPercentUsed() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      double var1;
      try {
         var1 = ((NotesBase)this).PropGetDouble(1506);
      } catch (Throwable var6) {
         throw var6;
      }

      return var1;
   }

   public DateTime getLastModified() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      DateTime var1;
      try {
         var1 = this.session.FindOrCreateDateTime(((NotesBase)this).PropGetDate(1007));
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public DateTime getLastFTIndexed() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      DateTime var1;
      try {
         var1 = this.session.FindOrCreateDateTime(((NotesBase)this).PropGetDate(1014));
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public DateTime getCreated() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      DateTime var1;
      try {
         var1 = this.session.FindOrCreateDateTime(((NotesBase)this).PropGetDate(1018));
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public ACL getACL() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      ACL var1;
      try {
         int var4 = ((NotesBase)this).PropGetAdt(1017);
         var1 = this.FindOrCreateACL(var4);
      } catch (Throwable var6) {
         throw var6;
      }

      return var1;
   }
}
