package lotus.notes.addins.ispy;

import lotus.domino.Database;
import lotus.domino.NotesException;
import lotus.domino.NotesFactory;
import lotus.domino.Session;
import lotus.domino.View;
import lotus.notes.addins.InternationalResources;
import lotus.notes.addins.JavaServerAddin;
import lotus.notes.internal.MessageQueue;

public class ISpy extends JavaServerAddin {
   private InternationalResources international_string = new InternationalResources("lotus/notes/addins/ispy/ISpyResources");
   private String addin_name;
   private int newStatusLineHandle;
   private MessageQueue msg_queue;
   private TCPPoller tcp_thread;
   private MailPoller mail_thread;
   private Session session;
   private int debug;
   protected static final String ispy_debug = "debug_ispy";

   public void runNotes() {
      int var1 = 0;

      try {
         this.session = NotesFactory.createSession();
      } catch (NotesException var14) {
         String var3 = this.international_string.getString("error_create_session");
         if (var14.text != null && var14.text != "") {
            var3 = var3 + ": " + var14.text;
         }

         ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + var3, 0);
         return;
      }

      try {
         String var2 = this.session.getEnvironmentString("debug_ispy", true);
         if (var2 != null) {
            this.debug = new Integer(var2);
         }
      } catch (NotesException var13) {
      }

      try {
         Runtime var4 = Runtime.getRuntime();
         this.newStatusLineHandle = ((JavaServerAddin)this).AddInCreateStatusLine(this.addin_name);
         ((JavaServerAddin)this).AddInSetStatusLine(this.newStatusLineHandle, this.international_string.getString("state_initializing"));
         if (this.debug > 1) {
            System.out.println("ISpy: Creating and opening message queue.");
         }

         this.msg_queue = new MessageQueue();
         String var19 = "MQ$ISPY";
         var1 = this.msg_queue.create(var19, 10, 0);
         if (var1 == 0) {
            var1 = this.msg_queue.open(var19.toString(), 0);
         }

         if (var1 != 0) {
            this.msg_queue = null;
            ((JavaServerAddin)this).AddInLogMessageText(this.addin_name + ": " + this.international_string.getString("error_no_message_queue"), 0);
         }

         this.waitForStatsAndEvents();
         if (this.debug > 1) {
            System.out.println("ISpy: Starting TCPPoller and MailPoller.");
         }

         this.tcp_thread = new TCPPoller(this.international_string);
         this.mail_thread = new MailPoller(this.international_string);
         this.tcp_thread.start();
         this.mail_thread.start();

         while(!this.tcp_thread.initialized() && !this.mail_thread.initialized()) {
            try {
               Thread.sleep(1000L);
            } catch (Exception var12) {
            }
         }

         ((JavaServerAddin)this).AddInSetStatusLine(this.newStatusLineHandle, this.international_string.getString("state_idle"));
         ((JavaServerAddin)this).AddInLogMessageText(this.addin_name + ": " + this.international_string.getString("state_initialization_complete"), 0);

         while(((JavaServerAddin)this).addInRunning()) {
            ((JavaServerAddin)this).OSPreemptOccasionally();
            if (this.msg_queue != null && this.msg_queue.isQuitPending()) {
               break;
            }

            if (!this.tcp_thread.currentlyProbing() && !this.mail_thread.currentlyProbing()) {
               ((JavaServerAddin)this).AddInSetStatusLine(this.newStatusLineHandle, this.international_string.getString("state_idle"));
            } else {
               ((JavaServerAddin)this).AddInSetStatusLine(this.newStatusLineHandle, this.international_string.getString("state_sending_probes"));
            }

            var4.runFinalization();
            var4.gc();
            if (!this.tcp_thread.isAlive() && !this.mail_thread.isAlive()) {
               break;
            }
         }
      } catch (NotesException var15) {
         if (var15.text != null && var15.text != "") {
            ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + var15.text, 0);
         }

         if (this.debug > 0 || var15.text == null || var15.text == "") {
            ((Throwable)var15).printStackTrace();
         }
      } catch (Exception var16) {
         String var5 = ((Throwable)var16).getMessage();
         if (var5 != null && var5 != "") {
            ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + var5, 0);
         }

         if (this.debug > 0 || var5 == null || var5 == "") {
            ((Throwable)var16).printStackTrace();
         }
      } finally {
         this.cleanUp();
         ((JavaServerAddin)this).AddInLogMessageText(this.addin_name + " " + this.international_string.getString("state_terminated"), 0);
      }

   }

   public static void main(String[] var0) {
      ISpy var1 = new ISpy();
      ((Thread)var1).start();
   }

   private void waitForStatsAndEvents() throws ISpyFatalException, NotesException, InterruptedException {
      if (this.debug > 1) {
         System.out.println("ISpy: Checking for Stats and Events database.");
      }

      String var1 = null;
      String var2 = this.international_string.getString("statistics_database_name");
      short var3 = 30000;
      Database var4 = null;

      try {
         boolean var7 = false;

         for(int var8 = 0; var8 < 10 && !var7; ++var8) {
            try {
               if (var4 == null) {
                  var4 = this.session.getDatabase((String)null, var2);
               }

               if (var4 != null) {
                  if (!var4.isOpen()) {
                     if (var4.open()) {
                        var7 = true;
                     }
                  } else {
                     var7 = true;
                  }
               }
            } catch (NotesException var25) {
               var1 = var25.text;
            } finally {
               if (!var7) {
                  Thread.sleep((long)var3);
               }

            }
         }

         if (!var7) {
            String var28 = this.international_string.getString("error_open_events_db");
            if (var1 != null && var1 != "") {
               var28 = var28 + ": " + var1;
            }

            throw new ISpyFatalException(var28);
         }

         if (this.debug > 1) {
            System.out.println("ISpy: Checking for mail and tcp probe views in Stats & Events data base.");
         }

         View var9 = null;
         View var10 = null;

         for(int var11 = 0; var11 < 10 && (var9 == null || var10 == null); ++var11) {
            try {
               if (var9 == null) {
                  var9 = var4.getView("va_MailProbes");
               }
            } catch (NotesException var24) {
               var9 = null;
            }

            try {
               if (var10 == null) {
                  var10 = var4.getView("va_TCPServices");
               }
            } catch (NotesException var23) {
               var10 = null;
            }

            if (var9 == null || var10 == null) {
               Thread.sleep((long)var3);
            }
         }

         if (var9 == null || var10 == null) {
            String var12 = this.international_string.getString("error_get_probe_views");
            throw new ISpyFatalException(var12);
         }
      } finally {
         if (var4 != null) {
            var4.recycle();
         }

      }

   }

   private void cleanUp() {
      if (this.msg_queue != null) {
         this.msg_queue.close(0);
      }

      ((JavaServerAddin)this).AddInSetStatusLine(this.newStatusLineHandle, this.addin_name + ": " + this.international_string.getString("state_terminating"));
      if (this.tcp_thread != null) {
         if (this.debug > 1) {
            System.out.println("ISpy: Stopping TCPPoller.");
         }

         this.tcp_thread.stopAddin();
         this.tcp_thread.interrupt();
      }

      if (this.mail_thread != null) {
         if (this.debug > 1) {
            System.out.println("ISpy: Stopping MailPoller.");
         }

         this.mail_thread.stopAddin();
         this.mail_thread.interrupt();
      }

      if (this.tcp_thread != null) {
         if (this.debug > 1) {
            System.out.println("ISpy: Waiting for TCPPoller to stop.");
         }

         try {
            this.tcp_thread.join();
         } catch (InterruptedException var2) {
         }
      }

      this.tcp_thread = null;
      if (this.mail_thread != null) {
         if (this.debug > 1) {
            System.out.println("ISpy: Waiting for MailPoller to stop.");
         }

         try {
            this.mail_thread.join();
         } catch (InterruptedException var1) {
         }
      }

      this.mail_thread = null;
      if (this.newStatusLineHandle != -1) {
         ((JavaServerAddin)this).AddInDeleteStatusLine(this.newStatusLineHandle);
      }

   }

   public ISpy() {
      this.addin_name = this.international_string.getString("addin_name");
      this.newStatusLineHandle = -1;
   }
}
