package lotus.notes.addins.ispy;

import java.util.Date;
import java.util.Enumeration;
import java.util.Vector;
import lotus.domino.Base;
import lotus.domino.Database;
import lotus.domino.DateTime;
import lotus.domino.DbDirectory;
import lotus.domino.Document;
import lotus.domino.DocumentCollection;
import lotus.domino.Item;
import lotus.domino.Log;
import lotus.domino.NotesException;
import lotus.domino.NotesFactory;
import lotus.domino.Session;
import lotus.domino.View;
import lotus.notes.addins.InternationalResources;
import lotus.notes.addins.JavaServerAddin;
import lotus.notes.addins.ispy.util.ActiveList;
import lotus.notes.addins.ispy.util.Appointment;
import lotus.notes.addins.ispy.util.Schedule;

public class MailPoller extends JavaServerAddin {
   private Session notes_session;
   private InternationalResources international_string;
   private String STAT_EVENTS_DB_NAME;
   private String INBOX_VIEW_NAME;
   private String MAIL_IN_RECORD_DESC;
   private String MAIL_TEMPLATE;
   private Database stat_events_db;
   String this_server;
   private DateTime last_schedule_update_time;
   private String addin_name;
   private String mail_server;
   private String mail_file;
   private Database incoming_mail_db;
   private String from_name;
   private String mail_domain;
   private Database outgoing_mail_db;
   private View mail_probes_view;
   private View inbox_view;
   protected boolean able_to_perform_mail_probing = false;
   private boolean currently_probing = false;
   private boolean initialized = false;
   private final int ONE_MINUTE = 60000;
   private int DEFAULT_POLL_TIME = 60000;
   private Schedule probe_schedule = new Schedule();
   private static String EVENT_QUEUE_NAME;
   private Log event_handle;
   private ActiveList stat_list = new ActiveList();
   Vector probe_list = new Vector();
   Date next_appointment;
   private boolean sent_event_error_messsage = false;
   private boolean mail_in_db_initialized = false;
   private final String CREATE_MAIL_IN_DB_PROXY_ACTION = "64";
   private String ADMIN_RQST_DB_NAME;
   private int debug;

   public MailPoller(InternationalResources var1) {
      this.international_string = var1;
      this.STAT_EVENTS_DB_NAME = var1.getString("statistics_database_name");
      this.addin_name = var1.getString("addin_name");
      this.INBOX_VIEW_NAME = var1.getString("view_inbox");
      EVENT_QUEUE_NAME = var1.getString("event_queue_name");
      this.ADMIN_RQST_DB_NAME = var1.getString("admin_request_db_name");
      this.MAIL_IN_RECORD_DESC = var1.getString("mail_in_record_description");
      this.MAIL_TEMPLATE = var1.getString("mail_template");
   }

   public boolean currentlyProbing() {
      return this.currently_probing;
   }

   public boolean initialized() {
      return this.initialized;
   }

   public void runNotes() {
      try {
         this.notes_session = NotesFactory.createSession();
         this.event_handle = this.notes_session.createLog("temp");
         this.from_name = this.addin_name + " on " + this.notes_session.getCommonUserName();
         this.this_server = this.notes_session.getUserName();
         String var1 = this.notes_session.getEnvironmentString("debug_ispy", true);
         if (var1 != null) {
            this.debug = new Integer(var1);
         }
      } catch (NotesException var32) {
         return;
      }

      this.initialized = true;

      try {
         while(((JavaServerAddin)this).addInRunning()) {
            try {
               this.getDatabasesAndViews();
               if (this.able_to_perform_mail_probing) {
                  this.initSchedule();
                  this.next_appointment = this.probe_schedule.getTimeOfNextAppointment();
                  if (this.next_appointment != null && this.next_appointment.getTime() < System.currentTimeMillis()) {
                     this.currently_probing = true;
                     if (this.debug > 0) {
                        Date var5 = new Date();
                        System.out.println(var5 + " ISpy: Starting mail probes...");
                     }

                     this.probe();
                     this.processReturnedProbes();
                  }
               }

               this.cleanupDatabasesAndViews();
            } catch (ISpyFatalException var24) {
               super.stopAddin();
               throw (ISpyFatalException)((Throwable)var24).fillInStackTrace();
            } catch (NotesException var25) {
               if (var25.text != null && var25.text != "") {
                  ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + var25.text, 0);
               }

               if (this.debug > 0) {
                  ((Throwable)var25).printStackTrace();
               }
            } catch (InterruptedException var26) {
               ((Thread)this).interrupt();
            } catch (Exception var27) {
               ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + ((Throwable)var27).getMessage(), 0);
               if (this.debug > 0) {
                  ((Throwable)var27).printStackTrace();
               }
            } finally {
               this.cleanupDatabasesAndViews();
               if (this.currently_probing) {
                  if (this.debug > 0) {
                     Date var33 = new Date();
                     System.out.println(var33 + " ISpy: ...MAIL probes complete.");
                  }

                  this.currently_probing = false;
               }

               this.sleep(this.next_appointment);
            }
         }
      } catch (ISpyFatalException var29) {
         String var4 = ((Throwable)var29).getMessage();
         if (var4 != null && var4.compareTo("") != 0) {
            ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + var4, 0);
         }

         ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + this.international_string.getString("mail_poller_fatal"), 0);
         if (this.debug > 0) {
            ((Throwable)var29).printStackTrace();
         }
      } catch (InterruptedException var30) {
      } finally {
         Vector var3 = this.stat_list.getList();
         this.deleteStats(var3);
      }

   }

   private void initSchedule() throws NotesException {
      try {
         Object var1 = null;
         Date var18 = new Date();
         DateTime var3 = this.notes_session.createDateTime("Today");
         var3.setNow();
         this.stat_list.reset();
         this.probe_schedule.reset();
         Object var4 = null;

         for(Document var5 = this.mail_probes_view.getFirstDocument(); var5 != null; var5 = var19) {
            try {
               if (var5.getItemValueString("Disabled") == null) {
                  boolean var8 = false;
                  Vector var17 = var5.getItemValue("SourceServerName");
                  Enumeration var9 = var17.elements();

                  while(var9.hasMoreElements()) {
                     String var10 = (String)var9.nextElement();
                     if (var10.compareTo(this.this_server) == 0 || var10.compareTo("*") == 0) {
                        var8 = true;
                        break;
                     }
                  }

                  if (var8) {
                     MailProbeDoc var11 = new MailProbeDoc(var5, this.from_name, this.international_string);
                     String var12 = var11.getStatisticName();
                     Appointment var20;
                     if (this.last_schedule_update_time == null) {
                        var20 = new Appointment(var18, (long)(var5.getItemValueInteger("MailProbeInterval") * '\uea60'), var11, var12);
                        this.probe_schedule.addAppointment(var20);
                     } else if (this.last_schedule_update_time.timeDifference(var5.getLastModified()) < 0) {
                        this.probe_schedule.getAppointmentWithDescription(var12, true);
                        var20 = new Appointment(var18, (long)(var5.getItemValueInteger("MailProbeInterval") * '\uea60'), var11, var12);
                        this.probe_schedule.addAppointment(var20);
                     } else {
                        var20 = this.probe_schedule.getAppointmentWithDescription(var12, false);
                        if (var20 != null) {
                           var20.activate();
                        }
                     }

                     if (var20 != null) {
                        this.stat_list.addItem(var12);
                     }
                  }
               }
            } finally {
               var19 = this.mail_probes_view.getNextDocument(var5);
               var5.recycle();
            }
         }

         this.probe_schedule.removeInActive();
         if (this.debug > 1) {
            System.out.println("\nISpy: DUMPING MAIL PROBE APPOINTMENTS");
         }

         this.probe_schedule.dump(this.debug);
         Vector var6 = this.stat_list.removeInActive();
         this.deleteStats(var6);
         if (this.debug > 1) {
            System.out.println("\nISpy: DUMPING MAIL POLLER STAT LIST");
         }

         this.stat_list.dump(this.debug);
         if (this.last_schedule_update_time != null) {
            this.last_schedule_update_time.recycle();
         }

         this.last_schedule_update_time = var3;
      } catch (NotesException var16) {
         String var2 = this.international_string.getString("error_init_sched");
         if (var16.text != null) {
            var16.text = var2 + ": " + var16.text;
         }

         throw (NotesException)((Throwable)var16).fillInStackTrace();
      }
   }

   private void probe() throws NotesException {
      try {
         while(this.next_appointment.getTime() < System.currentTimeMillis()) {
            Appointment var1 = (Appointment)this.probe_schedule.firstElement();
            var1.repeat();
            this.probe_schedule.removeElementAt(0);
            this.probe_schedule.addAppointment(var1);
            this.next_appointment = this.probe_schedule.getTimeOfNextAppointment();
            MailProbeDoc var9 = (MailProbeDoc)var1.getData();
            String var3 = var9.getTargetRecipient();
            Document var4 = this.outgoing_mail_db.createDocument();
            if (var4 != null) {
               DateTime var5 = this.notes_session.createDateTime("Today");
               var5.setNow();
               DateTime var6 = this.notes_session.createDateTime("Today");
               var6.setNow();
               var6.adjustMinute(var9.getMailTimeout());
               MailProbeID var7 = new MailProbeID(var9.getStatisticName(), var6);
               var4.appendItemValue("Form", "Memo");
               var4.appendItemValue("Body", this.international_string.getString("probe_body_text"));
               var4.appendItemValue("Recipients", var3);
               var4.appendItemValue("SendTo", var3);
               var4.appendItemValue("From", this.from_name);
               var4.appendItemValue("PostedDate", var5);
               var4.appendItemValue("Subject", var7.getIDString());
               var4.appendItemValue("DeliveryReport", "D");
               var4.appendItemValue("DeliveryPriority", "N");
               if (!var4.save()) {
                  this.logProbeError(var9, "error_mail_probe_save_failure");
                  ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + this.international_string.getString("error_mail_probe_save_failure") + " " + var9.getStatisticName(), 0);
               } else {
                  this.probe_list.addElement(var7.getIDString());
               }

               var5.recycle();
               Object var11 = null;
               var6.recycle();
               Object var12 = null;
               Object var10 = null;
               Object var13 = null;
            } else {
               this.logProbeError(var9, "error_mail_probe_create_failure");
               ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + this.international_string.getString("error_mail_probe_create_failure") + " " + var9.getStatisticName(), 0);
            }
         }

      } catch (NotesException var8) {
         String var2 = this.international_string.getString("error_probing");
         if (var8.text != null) {
            var8.text = var2 + ": " + var8.text;
         }

         throw (NotesException)((Throwable)var8).fillInStackTrace();
      }
   }

   private void processReturnedProbes() throws InterruptedException, NotesException {
      DateTime var1 = null;

      try {
         var1 = this.notes_session.createDateTime("Today");

         do {
            Document var17 = null;
            this.inbox_view.refresh();
            Document var4 = this.inbox_view.getFirstDocument();
            if (var4 != null) {
               do {
                  if (var17 != null) {
                     var17.remove(true);
                  }

                  String var6 = var4.getItemValueString("Subject");
                  String var7 = var4.getItemValueString("Form");
                  if (var6 != null && this.probe_list.removeElement(var6)) {
                     String var8 = MailProbeID.extractStatisticName(var6);
                     if (var7.compareTo(this.international_string.getString("probe_response_form")) == 0) {
                        if (this.stat_list.isActive(var8)) {
                           Vector var9 = var4.getItemValue("RouteTimes");
                           long var10 = (long)this.calculateMailResponseTime((DateTime)var9.elementAt(0), var4.getFirstItem("DeliveredDate"));
                           ((JavaServerAddin)this).StatUpdate(this.international_string.getString("facility_id"), var8, (short)0, (short)0, new Long(var10));
                           var9.removeAllElements();
                        }
                     } else {
                        Appointment var21 = this.probe_schedule.getAppointmentWithDescription(var8, false);
                        this.logProbeError((MailProbeDoc)var21.getData(), "error_probe_failed");
                     }
                  }

                  var17 = var4;
               } while((var4 = this.inbox_view.getNextDocument(var4)) != null);

               var17.remove(true);
            }

            var1.setNow();

            for(int var18 = 0; var18 < this.probe_list.size(); ++var18) {
               String var19 = (String)this.probe_list.elementAt(var18);
               String var20 = MailProbeID.extractStatisticName(var19);
               String var22 = MailProbeID.extractProbeExpiryTime(var19);
               if (var1.getLocalTime().compareTo(var22) >= 0) {
                  Appointment var23 = this.probe_schedule.getAppointmentWithDescription(var20, false);
                  this.logProbeError((MailProbeDoc)var23.getData(), "error_probe_timed_out");
                  this.probe_list.removeElementAt(var18);
               }
            }

            Thread.sleep(5000L);
         } while(this.probe_list.size() > 0 && System.currentTimeMillis() < this.next_appointment.getTime());
      } catch (NotesException var14) {
         String var5 = this.international_string.getString("error_mail_responses");
         if (var14.text != null) {
            var14.text = var5 + ": " + var14.text;
         }

         throw (NotesException)((Throwable)var14).fillInStackTrace();
      } finally {
         var1.recycle();
         Object var16 = null;
      }

   }

   private void deleteStats(Vector var1) {
      Enumeration var2 = var1.elements();

      while(var2.hasMoreElements()) {
         String var3 = (String)var2.nextElement();
         ((JavaServerAddin)this).StatDelete(this.international_string.getString("facility_id"), var3);
      }

   }

   private int calculateMailResponseTime(DateTime var1, Item var2) {
      int var3 = -1;
      Base var4 = null;

      try {
         var4 = var2.getDateTimeValue();
         var3 = var4.timeDifference(var1);
         var4.recycle();
         Object var10 = null;
      } catch (NotesException var6) {
         if (var4 != null) {
            try {
               var4.recycle();
            } catch (Exception var5) {
            }

            Object var8 = null;
         }

         var3 = -1;
      }

      return var3;
   }

   private void getDatabasesAndViews() throws ISpyFatalException {
      if (this.stat_events_db == null) {
         try {
            this.stat_events_db = this.notes_session.getDatabase((String)null, this.STAT_EVENTS_DB_NAME);
         } catch (NotesException var8) {
            throw new ISpyFatalException(this.international_string.getString("event_db_not_found") + " = " + this.STAT_EVENTS_DB_NAME);
         }

         if (this.stat_events_db == null) {
            throw new ISpyFatalException(this.international_string.getString("event_db_not_found") + " = " + this.STAT_EVENTS_DB_NAME);
         }

         boolean var1 = false;

         for(int var2 = 0; var2 < 3; ++var2) {
            try {
               this.openDB(this.stat_events_db);
               var1 = true;
               break;
            } catch (NotesException var9) {
               try {
                  Thread.sleep(5000L);
               } catch (InterruptedException var7) {
               }

               ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + this.international_string.getString("event_db_not_found") + "(" + var2 + ") = " + this.STAT_EVENTS_DB_NAME, 0);
            }
         }

         if (!var1) {
            throw new ISpyFatalException("");
         }
      }

      try {
         this.initializeMailInDb();
      } catch (NotesException var6) {
         ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + var6.text, 0);
      }

      if (this.mail_in_db_initialized) {
         try {
            this.outgoing_mail_db = null;
            this.incoming_mail_db = null;
            this.outgoing_mail_db = this.notes_session.getDatabase((String)null, "mail.box");
            this.incoming_mail_db = this.notes_session.getDatabase((String)null, this.mail_file);
         } catch (NotesException var5) {
         }

         if (this.outgoing_mail_db == null) {
            ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + this.international_string.getString("cant_open_mail_dot_box"), 0);
         }

         if (this.incoming_mail_db != null) {
            try {
               this.openDB(this.incoming_mail_db);
               this.inbox_view = null;
               this.inbox_view = this.incoming_mail_db.getView(this.INBOX_VIEW_NAME);
            } catch (NotesException var4) {
            }

            if (this.inbox_view == null) {
               ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + this.international_string.getString("no_view") + " = [" + this.INBOX_VIEW_NAME + "]!", 0);
            }
         } else {
            ((JavaServerAddin)this).AddInLogErrorText(this.addin_name + ": " + this.international_string.getString("no_mail_file") + " [" + this.mail_file + "].", 0);
         }
      }

      try {
         this.mail_probes_view = null;
         this.mail_probes_view = this.stat_events_db.getView("va_MailProbes");
      } catch (NotesException var3) {
      }

      if (this.mail_probes_view == null) {
         throw new ISpyFatalException(this.international_string.getString("no_view") + " = [" + "va_MailProbes" + "]! " + this.international_string.getString("refresh_events5"));
      } else {
         this.able_to_perform_mail_probing = this.outgoing_mail_db != null && this.incoming_mail_db != null && this.inbox_view != null && this.mail_probes_view != null && this.mail_in_db_initialized;
      }
   }

   private void initializeMailInDb() throws NotesException {
      boolean var1 = false;
      Database var2 = null;
      Database var3 = null;
      Document var4 = NABUtils.getFirstDocumentFromAddressBook(this.notes_session, 2, this.from_name);

      try {
         if (var4 == null) {
            try {
               var3 = this.notes_session.getDatabase((String)null, this.ADMIN_RQST_DB_NAME);
               this.openDB(var3);
            } catch (NotesException var31) {
               throw new NotesException(var31.id, this.international_string.getString("admin_rqst_db_not_found") + " " + this.ADMIN_RQST_DB_NAME);
            }

            if (!this.outstandingAdminpRequest(var3)) {
               Document var8 = null;

               Document var7;
               try {
                  String var11 = this.notes_session.getUserName();
                  var8 = NABUtils.getFirstDocumentFromAddressBook(this.notes_session, 0, var11);
                  String var12 = var8.getItemValueString("Domain");
                  var7 = var3.createDocument();
                  Item var13 = var7.appendItemValue("Form", "AdminRequest");
                  var13.setSigned(true);
                  var13 = var7.appendItemValue("ProxyNameList", this.from_name);
                  var13.setSigned(true);
                  var13 = var7.appendItemValue("ProxyServer", "*");
                  var13.setSigned(true);
                  var13 = var7.appendItemValue("ProxyAuthor", var11);
                  var13.setSigned(true);
                  var13 = var7.appendItemValue("ProxyProcess", "Adminp");
                  var13.setSigned(true);
                  var13 = var7.appendItemValue("ProxyAction", "64");
                  var13.setSigned(true);
                  var13 = var7.appendItemValue("ProxyDatabaseSourcePath", "mail\\ispy50.nsf");
                  var13.setSigned(true);
                  var13 = var7.appendItemValue("ProxyTextItem1", this.MAIL_IN_RECORD_DESC);
                  var13.setSigned(true);
                  var13 = var7.appendItemValue("ProxyTextItem2", var12);
                  var13.setSigned(true);
                  var13 = var7.appendItemValue("Type", "AdminRequest");
                  var13.setSigned(true);
                  var13 = var7.appendItemValue("ProxySourceServer", var11);
                  var13.setSigned(true);
                  var7.sign();
               } catch (NotesException var28) {
                  throw new NotesException(var28.id, this.international_string.getString("error_create_adminp_rqst"));
               } finally {
                  if (var8 != null) {
                     Database var38 = var8.getParentDatabase();
                     var38.recycle();
                  }

               }

               if (!var7.save()) {
                  throw new NotesException(0, this.international_string.getString("error_create_adminp_rqst"));
               }
            }
         } else {
            DbDirectory var36;
            try {
               this.mail_file = var4.getItemValueString("MailFile");
               var36 = this.notes_session.getDbDirectory((String)null);
            } catch (NotesException var30) {
               throw new NotesException(var30.id, this.international_string.getString("error_check_for_mailfile"));
            }

            try {
               var2 = var36.openDatabase(this.mail_file);
            } catch (NotesException var29) {
            }

            try {
               if (var2 == null) {
                  Database var35 = this.notes_session.getDatabase((String)null, this.MAIL_TEMPLATE);
                  this.openDB(var35);
                  var2 = var35.createFromTemplate((String)null, this.mail_file, true);
                  var2.setTitle(var4.getItemValueString("FullName"));
               }

               var1 = true;
            } catch (NotesException var32) {
               String var9 = this.international_string.getString("error_create_mail_file");
               if (var32.text != null) {
                  var9 = var9 + ": " + var32.text;
               }

               throw new NotesException(var32.id, var9);
            }
         }
      } finally {
         this.mail_in_db_initialized = var4 != null && var1;
         if (var2 != null) {
            var2.recycle();
         }

         if (var3 != null) {
            var3.recycle();
         }

         if (var4 != null) {
            Database var37 = var4.getParentDatabase();
            var37.recycle();
         }

      }

   }

   private boolean outstandingAdminpRequest(Database var1) throws NotesException {
      try {
         String var2 = new String("SELECT Form=\"AdminRequest\" & ProxyAction=\"") + "64" + "\"";
         DocumentCollection var3 = var1.search(var2);

         for(Document var4 = var3.getFirstDocument(); var4 != null; var4 = var3.getNextDocument(var4)) {
            DocumentCollection var5 = var4.getResponses();
            if (var5.getCount() == 0) {
               return true;
            }
         }

         return false;
      } catch (NotesException var6) {
         throw new NotesException(var6.id, this.international_string.getString("error_outstanding_adminp_rqst"));
      }
   }

   private void sleep(Date var1) throws InterruptedException {
      if (!((JavaServerAddin)this).shouldTerminate()) {
         long var2 = 0L;
         if (var1 == null) {
            var2 = (long)this.DEFAULT_POLL_TIME;
         } else {
            var2 = var1.getTime() - System.currentTimeMillis();
            if (var2 < 0L) {
               var2 = 0L;
            } else if (var2 > (long)this.DEFAULT_POLL_TIME) {
               var2 = (long)this.DEFAULT_POLL_TIME;
            }
         }

         Thread.sleep(var2);
      }

   }

   private void cleanupDatabasesAndViews() {
      try {
         if (this.incoming_mail_db != null) {
            this.incoming_mail_db.recycle();
            this.incoming_mail_db = null;
         }
      } catch (Exception var2) {
      }

      try {
         if (this.outgoing_mail_db != null) {
            this.outgoing_mail_db.recycle();
            this.outgoing_mail_db = null;
            return;
         }
      } catch (Exception var1) {
      }

   }

   private void openDB(Database var1) throws NotesException {
      if (!var1.isOpen()) {
         var1.open();
      }

   }

   private void logProbeError(MailProbeDoc var1, String var2) {
      if (this.stat_list.isActive(var1.getStatisticName()) && var1 != null) {
         boolean var3 = false;
         ((JavaServerAddin)this).StatUpdate(this.international_string.getString("facility_id"), var1.getStatisticName(), (short)0, (short)0, new Long(-1L));

         try {
            String var4 = this.international_string.getString(var2) + " " + this.international_string.getString("facility_id") + "." + var1.getStatisticName();
            this.event_handle.logEvent(var4, EVENT_QUEUE_NAME, 3, var1.getSeverity());
         } catch (NotesException var5) {
            if (!var3) {
               ((JavaServerAddin)this).AddInLogMessageText(this.addin_name + ": " + this.international_string.getString("logevent_failure"), 0);
            }

         }
      }
   }
}
