package lotus.notes.addins.ispy;

import java.util.Vector;
import lotus.domino.Document;
import lotus.domino.NotesException;
import lotus.notes.addins.InternationalResources;

public final class TCPProbeDoc {
   public static final String TCP_SERVICE_VIEW = "va_TCPServices";
   public static final String FORM_NAME = "fa_TCPServices";
   public static final String TARGET_SERVER = "TargetServerName";
   public static final String TCP_TIMEOUT = "TCPTimeOut";
   public static final String TCP_PROBE_INTERVAL = "TCPProbeInterval";
   public static final String HTTP_URL = "HTTPUrl";
   public static final String HTTP_URL_FETCH = "HTTPUrlFetch";
   public static final String NNTP_COMMAND_SEND = "NNTPCommandSend";
   public static final String NNTP_COMMAND = "NNTPCommand";
   public static final String NNTP_PARAMETERS = "NNTPParameters";
   public static final String NNTP_GROUP = "NNTPGroup";
   public static final String DISABLED_FLAG = "Disabled";
   public static final String EVENT_SEVERITY = "Severity";
   public static final String SOURCE_SERVER = "SourceServerName";
   public static final String ALL_SELF_MONITOR = "AllSelfMonitor";
   public static final String MONITOR_NUMBER = "MonitorNumber";
   public static final String SERVICES = "Services";
   public static final String ALL_SERVICES = "AllServices";
   public static final String ALL_TARGET_SERVERS = "AllTargetServers";
   public static final String DNS_SVC = "DNS";
   public static final String FTP_SVC = "FTP";
   public static final String HTTP_SVC = "HTTP";
   public static final String IMAP_SVC = "IMAP";
   public static final String LDAP_SVC = "LDAP";
   public static final String NNTP_SVC = "NNTP";
   public static final String POP3_SVC = "POP3";
   public static final String SMTP_SVC = "SMTP";
   public static final String[] LIST_OF_SERVICES = new String[]{new String("DNS"), new String("FTP"), new String("HTTP"), new String("IMAP"), new String("LDAP"), new String("NNTP"), new String("POP3"), new String("SMTP")};
   public static final int[] EVENT_TYPES = new int[]{11, 21, 19, 3, 3, 20, 3, 3};
   private String target_server;
   private int timeout;
   private int probe_interval;
   private int severity;
   private String http_url;
   private String http_url_fetch;
   private String nntp_cmd_send;
   private String nntp_cmd;
   private String nntp_paramaters;
   private String nntp_group;
   private String monitor_number;
   private Vector services;
   private String self_monitor;
   private String all_services;
   String stat_resp_time_str;

   public TCPProbeDoc(Document var1, String var2, InternationalResources var3) throws NotesException {
      this.timeout = var1.getItemValueInteger("TCPTimeOut");
      this.probe_interval = var1.getItemValueInteger("TCPProbeInterval");
      Integer var4 = new Integer(var1.getItemValueString("Severity"));
      this.severity = var4;
      this.http_url_fetch = var1.getItemValueString("HTTPUrlFetch");
      if (this.http_url_fetch.compareTo("1") == 0) {
         this.http_url = var1.getItemValueString("HTTPUrl");
      }

      this.nntp_cmd_send = var1.getItemValueString("NNTPCommandSend");
      if (this.nntp_cmd_send.compareTo("1") == 0) {
         this.nntp_cmd = var1.getItemValueString("NNTPCommand");
         this.nntp_paramaters = var1.getItemValueString("NNTPParameters");
         this.nntp_group = var1.getItemValueString("NNTPGroup");
      }

      this.monitor_number = var1.getItemValueString("MonitorNumber");
      this.services = var1.getItemValue("Services");
      this.self_monitor = var1.getItemValueString("AllSelfMonitor");
      this.all_services = var1.getItemValueString("AllServices");
      this.target_server = var2;
      this.stat_resp_time_str = var3.getString("stat_response_time_str");
   }

   public String getStatisticName(int var1) {
      new String();
      String var2 = LIST_OF_SERVICES[var1] + "." + this.target_server + "." + this.monitor_number + "." + this.stat_resp_time_str;
      return var2;
   }

   public String getStatisticName(String var1) {
      new String();
      String var2 = var1 + "." + this.target_server + "." + this.monitor_number + "." + this.stat_resp_time_str;
      return var2;
   }

   public boolean isServiceEnabled(String var1) {
      return this.services.contains(var1);
   }

   public boolean isServiceEnabled(int var1) {
      return this.isServiceEnabled(LIST_OF_SERVICES[var1]);
   }

   public String getTargetServer() {
      return this.target_server;
   }

   public int getTimeout() {
      return this.timeout;
   }

   public int getProbeInterval() {
      return this.probe_interval;
   }

   public int getSeverity() {
      return this.severity;
   }

   public String getHttpUrl() {
      return this.http_url;
   }

   public String getNntpCommand() {
      return this.nntp_cmd;
   }

   public String getNntpParameters() {
      return this.nntp_paramaters;
   }

   public String getNntpGroup() {
      return this.nntp_group;
   }

   public String getMonitorNumber() {
      return this.monitor_number;
   }

   public Vector getServices() {
      return this.services;
   }

   public boolean selfMonitor() {
      return this.self_monitor != null;
   }

   public boolean allServices() {
      return this.all_services != null && this.all_services.compareTo("1") == 0;
   }

   public String getDescription() {
      StringBuffer var1 = new StringBuffer(this.target_server);
      var1.append(" ");
      var1.append(this.monitor_number);
      return var1.toString();
   }

   public static String getDescription(String var0, Document var1) throws NotesException {
      StringBuffer var2 = new StringBuffer(var0);
      var2.append(" ");
      String var3 = var1.getItemValueString("MonitorNumber");
      var2.append(var3);
      return var2.toString();
   }

   public static int getEventType(String var0) {
      try {
         int var1 = getServiceIdx(var0);
         return EVENT_TYPES[var1];
      } catch (NotesException var2) {
         return 7;
      }
   }

   private static int getServiceIdx(String var0) throws NotesException {
      for(int var1 = 0; var1 < LIST_OF_SERVICES.length; ++var1) {
         if (var0.compareTo(LIST_OF_SERVICES[var1]) == 0) {
            return var1;
         }
      }

      throw new NotesException(0, "");
   }
}
