package lotus.notes.addins.ispy.net.dns;

import java.io.PrintStream;
import lotus.notes.addins.ispy.net.BinaryConnection;

public class DNSHeader {
   public static final int BYTE_SIZE = 12;
   public static final int OPCODE_QUERY = 0;
   public static final int OPCODE_IQUERY = 1;
   public static final int OPCODE_STATUS = 2;
   public static final boolean QR_QUERY = false;
   public static final boolean QR_RESPONSE = true;
   public static final int RCODE_NOERROR = 0;
   public static final int RCODE_FORMATERROR = 1;
   public static final int RCODE_SERVERFAILURE = 2;
   public static final int RCODE_NAMEERROR = 3;
   public static final int RCODE_NOTIMPLEMENTED = 4;
   public static final int RCODE_REFUSED = 5;
   private static final int MASK_BYTE = 255;
   private static final byte BIT_QR = -128;
   private static final byte BIT_OPCODE = 8;
   private static final byte MASK_OPCODE = 120;
   private static final byte BIT_AA = 4;
   private static final byte BIT_TC = 2;
   private static final byte BIT_RD = 1;
   private static final byte BIT_RA = -128;
   private static final byte BIT_RCODE = 1;
   private static final byte MASK_RCODE = 15;
   private int m_id;
   private boolean m_qr = false;
   private int m_opcode = 0;
   private boolean m_aa = false;
   private boolean m_tc = false;
   private boolean m_rd = false;
   private boolean m_ra = false;
   private int m_rcode = 0;
   private int m_qdcount;
   private int m_ancount;
   private int m_nscount;
   private int m_arcount;

   public DNSHeader() {
   }

   public DNSHeader(int var1, boolean var2, int var3, boolean var4, boolean var5, boolean var6, boolean var7, int var8, int var9, int var10, int var11, int var12) {
      this.m_id = var1;
      this.m_qr = var2;
      this.m_opcode = var3;
      this.m_aa = var4;
      this.m_tc = var5;
      this.m_rd = var6;
      this.m_ra = var7;
      this.m_rcode = var8;
      this.m_qdcount = var9;
      this.m_ancount = var10;
      this.m_nscount = var11;
      this.m_arcount = var12;
   }

   public DNSHeader(byte[] var1, int var2) {
      int var3 = (var1[var2] & 255) * 256;
      int var4 = var1[var2 + 1] & 255;
      this.m_id = var3 + var4;
      this.m_qr = (var1[var2 + 2] & -128) != 0;
      this.m_aa = (var1[var2 + 2] & 4) != 0;
      this.m_tc = (var1[var2 + 2] & 2) != 0;
      this.m_rd = (var1[var2 + 2] & 1) != 0;
      this.m_opcode = (var1[var2 + 2] & 120) / 8;
      this.m_ra = (var1[var2 + 3] & -128) != 0;
      this.m_rcode = var1[var2 + 3] & 15;
      var3 = (var1[var2 + 4] & 255) * 256;
      var4 = var1[var2 + 5] & 255;
      this.m_qdcount = var3 + var4;
      var3 = (var1[var2 + 6] & 255) * 256;
      var4 = var1[var2 + 7] & 255;
      this.m_ancount = var3 + var4;
      var3 = (var1[var2 + 8] & 255) * 256;
      var4 = var1[var2 + 9] & 255;
      this.m_nscount = var3 + var4;
      var3 = (var1[var2 + 10] & 255) * 256;
      var4 = var1[var2 + 11] & 255;
      this.m_arcount = var3 + var4;
   }

   public void setId(char var1) {
      this.m_id = var1;
   }

   public void setQr(boolean var1) {
      this.m_qr = var1;
   }

   public void setOpcode(int var1) {
      this.m_opcode = var1;
   }

   public void setAa(boolean var1) {
      this.m_aa = var1;
   }

   public void setTc(boolean var1) {
      this.m_tc = var1;
   }

   public void setRd(boolean var1) {
      this.m_rd = var1;
   }

   public void setRa(boolean var1) {
      this.m_ra = var1;
   }

   public void setRcode(int var1) {
      this.m_rcode = var1;
   }

   public void setQdcount(int var1) {
      this.m_qdcount = var1;
   }

   public void setAncount(int var1) {
      this.m_ancount = var1;
   }

   public void setNscount(int var1) {
      this.m_nscount = var1;
   }

   public void setArcount(int var1) {
      this.m_arcount = var1;
   }

   public int getId() {
      return this.m_id;
   }

   public boolean getQr() {
      return this.m_qr;
   }

   public int getOpcode() {
      return this.m_opcode;
   }

   public boolean getAa() {
      return this.m_aa;
   }

   public boolean getTc() {
      return this.m_tc;
   }

   public boolean getRd() {
      return this.m_rd;
   }

   public boolean getRa() {
      return this.m_ra;
   }

   public int getRcode() {
      return this.m_rcode;
   }

   public int getQdcount() {
      return this.m_qdcount;
   }

   public int getAncount() {
      return this.m_ancount;
   }

   public int getNscount() {
      return this.m_nscount;
   }

   public int getArcount() {
      return this.m_arcount;
   }

   public synchronized byte[] toByteArray() {
      byte[] var1 = new byte[12];
      var1[0] = (byte)(this.m_id / 256);
      var1[1] = (byte)(this.m_id % 256);
      var1[2] = (byte)(this.m_opcode * 8);
      if (this.m_qr) {
         var1[2] |= -128;
      }

      if (this.m_aa) {
         var1[2] = (byte)(var1[2] | 4);
      }

      if (this.m_tc) {
         var1[2] = (byte)(var1[2] | 2);
      }

      if (this.m_rd) {
         var1[2] = (byte)(var1[2] | 1);
      }

      var1[3] = (byte)this.m_rcode;
      if (this.m_ra) {
         var1[3] |= -128;
      }

      var1[4] = (byte)(this.m_qdcount / 256);
      var1[5] = (byte)(this.m_qdcount % 256);
      var1[6] = (byte)(this.m_ancount / 256);
      var1[7] = (byte)(this.m_ancount % 256);
      var1[8] = (byte)(this.m_nscount / 256);
      var1[9] = (byte)(this.m_nscount % 256);
      var1[10] = (byte)(this.m_arcount / 256);
      var1[11] = (byte)(this.m_arcount % 256);
      return var1;
   }

   public String toString() {
      StringBuffer var1 = new StringBuffer(80);
      var1.append("ID=");
      var1.append(Integer.toString(this.m_id));
      var1.append("\nQR=");
      if (this.m_qr) {
         var1.append('1');
      } else {
         var1.append('0');
      }

      var1.append("\nOPCODE=");
      var1.append(Integer.toString(this.m_opcode));
      var1.append("\nAA=");
      if (this.m_aa) {
         var1.append('1');
      } else {
         var1.append('0');
      }

      var1.append("\nTC=");
      if (this.m_tc) {
         var1.append('1');
      } else {
         var1.append('0');
      }

      var1.append("\nRD=");
      if (this.m_rd) {
         var1.append('1');
      } else {
         var1.append('0');
      }

      var1.append("\nRA=");
      if (this.m_ra) {
         var1.append('1');
      } else {
         var1.append('0');
      }

      var1.append("\nRCODE=");
      var1.append(Integer.toString(this.m_rcode));
      var1.append("\nQDCOUNT=");
      var1.append(Integer.toString(this.m_qdcount));
      var1.append("\nANCOUNT=");
      var1.append(Integer.toString(this.m_ancount));
      var1.append("\nNSCOUNT=");
      var1.append(Integer.toString(this.m_nscount));
      var1.append("\nARCOUNT=");
      var1.append(Integer.toString(this.m_arcount));
      return var1.toString();
   }

   public String toHexString() {
      byte[] var1 = this.toByteArray();
      return BinaryConnection.toHexString(var1);
   }

   public static boolean test(PrintStream var0) {
      DNSHeader var1 = new DNSHeader();
      var0.println(var1.getClass().getName());
      boolean var2 = true;
      var0.print(".toString() - ");
      String var3 = "ID=0\nQR=0\nOPCODE=0\nAA=0\nTC=0\nRD=0\nRA=0\nRCODE=0\nQDCOUNT=0\nANCOUNT=0\nNSCOUNT=0\nARCOUNT=0";
      if (!var3.equals(var1.toString())) {
         var0.println("FAILED - " + var1.toString());
         var2 = false;
      } else {
         var0.println("PASSED");
      }

      var0.print(".set*() - ");
      char var5 = 1000;
      var1.setId(var5);
      var1.setOpcode(1);
      var1.setTc(true);
      var1.setRcode(5);
      ++var5;
      var1.setQdcount(var5);
      ++var5;
      var1.setAncount(var5);
      ++var5;
      var1.setNscount(var5);
      ++var5;
      var1.setArcount(var5);
      String var6 = "ID=1000\nQR=0\nOPCODE=1\nAA=0\nTC=1\nRD=0\nRA=0\nRCODE=5\nQDCOUNT=1001\nANCOUNT=1002\nNSCOUNT=1003\nARCOUNT=1004";
      if (!var6.equals(var1.toString())) {
         var0.println("FAILED - " + var1.toString());
         var2 = false;
      } else {
         var0.println("PASSED");
      }

      var0.print(".toByteArray() - ");
      byte[] var7 = var1.toByteArray();
      byte[] var8 = new byte[]{3, -24, 10, 5, 3, -23, 3, -22, 3, -21, 3, -20};
      boolean var9 = true;

      for(int var10 = 0; var10 < var7.length; ++var10) {
         if (var7[var10] != var8[var10]) {
            var9 = false;
         }
      }

      if (!var9) {
         var0.println("FAILED");
      } else {
         var0.println("PASSED");
      }

      var0.print(".DNSHeader(byte[], int) - ");
      DNSHeader var11 = new DNSHeader(var7, 0);
      if (!var6.equals(var11.toString())) {
         var0.println("FAILED - " + var11.toString());
         var2 = false;
      } else {
         var0.println("PASSED");
      }

      return var2;
   }

   public static void main(String[] var0) {
      test(System.out);
   }
}
