package lotus.notes.addins.ispy.net.portcheck;

import java.io.IOException;
import java.net.InetAddress;
import lotus.notes.addins.ispy.net.Connection;
import lotus.notes.addins.ispy.net.TextConnection;

public class NNTPCheck extends TextPortCheck {
   public static final int PORT = 119;
   private String m_command;
   private String m_group;
   private boolean text_follows = false;
   private String success_indicator;
   private TextConnection tconnection;

   public NNTPCheck() {
      super("Network News Transfer Protocol", "NNTP", 119);
   }

   public void setCommand(String var1, String var2, String var3) {
      if (var3 != null) {
         this.m_command = var1.toUpperCase() + " " + var3;
      } else {
         this.m_command = var1;
      }

      this.m_group = var2;
      this.text_follows = false;
      if (this.m_command != null) {
         if (this.m_command.startsWith("HELP")) {
            this.text_follows = true;
            this.success_indicator = new String("100");
            return;
         }

         if (this.m_command.startsWith("IHAVE") || this.m_command.startsWith("POST")) {
            this.success_indicator = new String("3");
            return;
         }

         this.success_indicator = new String("2");
         if (this.m_command.startsWith("ARTICLE") || this.m_command.startsWith("BODY") || this.m_command.startsWith("HEAD") || this.m_command.startsWith("LIST") || this.m_command.startsWith("NEWGROUPS") || this.m_command.startsWith("NEWNEWS") || this.m_command.startsWith("XOVER")) {
            this.text_follows = true;
         }
      }

   }

   public void start(PortCheckListener var1, InetAddress var2, int var3) {
      String[] var4;
      if (this.m_command != null) {
         if (this.m_group != null) {
            var4 = new String[]{"S:2", "C:GROUP " + this.m_group, "S:2", "C:" + this.m_command, "C:QUIT"};
         } else {
            var4 = new String[]{"S:2", "C:" + this.m_command, "C:QUIT"};
         }
      } else {
         var4 = new String[]{"S:2", "C:QUIT"};
      }

      super.start(var1, var2, var3, var4);
   }

   protected void converse(Connection var1, PortCheckEvent var2) {
      var2.status.bitset.set(1);

      try {
         int var3 = 0;
         int var4 = 0;

         for(int var5 = 0; var5 < super.m_expected.length; ++var5) {
            if (super.m_expected[var5].startsWith("S:")) {
               var3 |= 1;
            } else if (super.m_expected[var5].startsWith("C:")) {
               var3 |= 2;
            }
         }

         var2.openMillis = System.currentTimeMillis();
         var1.open(((PortCheck)this).getHost(), ((PortCheck)this).getPort(), ((PortCheck)this).getTimely(), var3);
         var2.status.bitset.set(2);
         boolean var6 = true;
         boolean var7 = false;
         this.tconnection = (TextConnection)var1;

         for(int var8 = 0; var8 < super.m_expected.length; ++var8) {
            if (var7) {
               var7 = false;
               String var9 = this.tconnection.readLine();
               var2.transactions[var8] = "S:" + var9;
               if (!var9.startsWith(this.success_indicator)) {
                  var6 = false;
                  var4 = var8;
                  break;
               }

               if (this.text_follows) {
                  Object var10 = null;

                  do {
                     var13 = this.tconnection.readLine();
                  } while(var13 != null && var13.compareTo(".") != 0);
               }
            }

            if (super.m_expected[var8].startsWith("C:")) {
               var2.transactions[var8] = super.m_expected[var8];
               this.tconnection.println(super.m_expected[var8].substring("C:".length()));
               this.tconnection.flush();
               if (this.m_command != null && super.m_expected[var8].startsWith("C:" + this.m_command)) {
                  var7 = true;
               }
            } else if (super.m_expected[var8].startsWith("S:")) {
               var2.transactions[var8] = "S:" + this.tconnection.readLine();
               if (!var2.transactions[var8].startsWith(super.m_expected[var8])) {
                  var6 = false;
                  var4 = var8;
                  break;
               }
            }
         }

         if (var6) {
            var2.status.bitset.set(3);
         } else {
            var2.transactions[var4] = super.m_expected[super.m_expected.length - 1];
            this.tconnection.println(super.m_expected[super.m_expected.length - 1].substring("C:".length()));
            this.tconnection.flush();
         }

         var1.close();
         var2.closeMillis = System.currentTimeMillis();
      } catch (IOException var12) {
         if (this.tconnection != null) {
            try {
               this.tconnection.close();
            } catch (IOException var11) {
            }
         }

         var2.closeMillis = System.currentTimeMillis();
         var2.message = ((Throwable)var12).getMessage();
      }

      if (var2.closeMillis - var2.openMillis <= (long)super.m_timely) {
         var2.status.bitset.set(4);
      }

   }
}
