package lotus.notes.apps.reports;

import Acme.JPM.Encoders.GifEncoder;
import Acme.JPM.Encoders.ImageEncoder;
import java.awt.Color;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Frame;
import java.awt.Graphics;
import java.awt.Image;
import java.io.File;
import java.io.FileOutputStream;
import java.util.Date;
import java.util.Vector;

public class RepChart {
   public static final int cNoChart = 0;
   public static final int cPieChart = 1;
   public static final int cBarChart = 2;
   public static final int cAllItems = -1;
   public static final int cMinChartItems = 10;
   public static final boolean cUseLegend = true;
   public static final boolean cNoLegend = false;
   public static final boolean cUseAxis = true;
   public static final boolean cNoAxis = false;
   public static final String cRectShape = "RECT";
   public static final String cPolyShape = "POLYGON";
   public static final String cCircleShape = "CIRCLE";
   public static final int cPieChartSize = 250;
   public static final int cPieChartLeftMargin = 100;
   public static final int cBarChartHeight = 250;
   public static final int cBarChartWidth = 500;
   public static final int cBarChartLeftMargin = 10;
   public static final int cLegendExtra = 180;
   public static final int cAxisExtra = 40;
   public static final int cColorKeyBoxSize = 20;
   public static final int cChartHorizMargin = 10;
   public static final int cChartVertMargin = 2;
   public static final int cBarVertMarginPct = 20;
   public static final int cBarMaxHeight = 246;
   public static final int cGridDivisions = 10;
   public static final int cGridLabelSpace = 10;
   public static final int cGridFontSize = 10;
   public static final int cGridFontStyle = 0;
   public static final String cGridFontFace = "Ariel";
   private String cBadChartError;
   public static final String cGifExt = ".gif";
   private InternationalResources international_string = new InternationalResources("lotus/notes/apps/reports/ReportsResources");
   private static Vector sRowColors = new Vector();
   private static Vector sBarColors;
   protected int mChartType;
   protected int mChartWidth;
   protected int mChartHeight;
   protected int mAxisHeight;
   protected int mChartItemMax;
   protected boolean mUseLegend;
   protected boolean mUseAxis;
   protected int mAxisWidth;
   protected String mAxisDelims;
   protected Vector mLabels;
   protected Vector mValues;
   protected String mChartSpec = "";
   protected Vector mColorKeyBoxSpecs = new Vector();
   protected Vector mColorKeyHexStrings = new Vector();
   protected Vector mAreaCoords = new Vector();
   protected String mAreaShape = new String("RECT");
   protected int mCycleCount;
   protected Image mImage;
   Frame mImageWin;

   public static void writeImageAsGif(Image var0, String var1) throws Exception {
      FileOutputStream var2 = null;

      try {
         Class.forName("Acme.JPM.Encoders.GifEncoder");
         var2 = new FileOutputStream(var1);
         GifEncoder var7 = new GifEncoder(var0, var2);
         ((ImageEncoder)var7).encode();
         var2.close();
      } catch (ClassNotFoundException var5) {
         try {
            var2.close();
         } catch (Exception var4) {
         }

         File var3 = new File(var1);
         var3.delete();
         throw new Exception("no_acme_package");
      }
   }

   public int getChartType() {
      return this.mChartType;
   }

   public int getChartWidth() {
      return this.mChartWidth;
   }

   public int getChartHeight() {
      return this.mChartHeight;
   }

   public int getChartItemMax() {
      return this.mChartItemMax;
   }

   public boolean useLegend() {
      return this.mUseLegend;
   }

   public boolean useAxis() {
      return this.mUseAxis;
   }

   public int axisWidth() {
      return this.mAxisWidth;
   }

   public String axisDelims() {
      return this.mAxisDelims;
   }

   public Vector getLabels() {
      return this.mLabels;
   }

   public Vector getValues() {
      return this.mValues;
   }

   public Vector getColorKeyBoxSpecs() {
      return this.mColorKeyBoxSpecs;
   }

   public Vector getColorKeyHexStrings() {
      return this.mColorKeyHexStrings;
   }

   public Vector getAreaCoords() {
      return this.mAreaCoords;
   }

   public String getAreaShape() {
      return this.mAreaShape;
   }

   public Image getImage() {
      return this.mImage;
   }

   public RepChart(RepDef var1, Vector var2, Vector var3) {
      this.cBadChartError = this.international_string.getString("bad_chart_data");
      this.mChartType = var1.getChartType();
      this.mUseLegend = var1.useLegend();
      this.mUseAxis = var1.useAxis();
      this.mAxisWidth = var1.getAxisWidth();
      this.mAxisDelims = var1.getAxisDelims();
      this.mLabels = var2;
      this.mValues = var3;

      try {
         var1.getChartItemMax();
         this.mChartItemMax = this.mChartItemMax == -1 ? var3.size() : this.mChartItemMax;
         this.mChartItemMax = Math.max(this.mChartItemMax, 10);
         this.mImageWin = new Frame();
         this.mImageWin.addNotify();
         this.mAxisHeight = 0;
         switch (this.mChartType) {
            case 1:
               this.mChartWidth = 250 + (this.mUseLegend ? 0 : 180);
               this.mChartHeight = 250 + (this.mUseLegend ? 0 : 180);
               break;
            case 2:
               this.mChartWidth = 500 + (this.mUseLegend ? 0 : 180);
               this.mChartHeight = 250;
               if (this.mUseAxis) {
                  this.mAxisHeight = 40;
               }
         }

         this.makeColorKeyHexStrings();
         this.makeChart();
      } catch (Exception var5) {
         ((Throwable)var5).printStackTrace();
      }
   }

   public void writeAsGif(String var1) throws Exception {
      if (this.mImage != null) {
         writeImageAsGif(this.mImage, var1);
      }
   }

   public String writeAsTempGif(String var1) throws Exception {
      this.mChartSpec = this.makeTempSpec(var1);
      this.writeAsGif(this.mChartSpec);
      return this.mChartSpec;
   }

   public synchronized String makeTempSpec(String var1) {
      ++this.mCycleCount;
      if (this.mCycleCount > 1000) {
         this.mCycleCount = 0;
      }

      Date var2 = new Date();
      long var3 = var2.getTime();
      return var1 + var3 + "-" + this.mCycleCount + ".gif";
   }

   public void writeColorKeyBoxes(String var1) throws Exception {
      this.mColorKeyBoxSpecs.removeAllElements();
      int var2 = Math.min(this.mChartItemMax, this.mValues.size());
      var2 = Math.min(var2, sRowColors.size());

      for(int var3 = 0; var3 < var2; ++var3) {
         Color var4 = this.getColorForBar(var3);
         if (var4 != null) {
            String var5 = this.makeColorHexString(var4);
            String var6 = var1 + var5 + ".gif";
            this.mColorKeyBoxSpecs.addElement(var6);
            File var7 = new File(var6);
            if (!var7.exists()) {
               Image var8 = this.mImageWin.createImage(20, 20);
               if (var8 == null) {
                  return;
               }

               Graphics var9 = var8.getGraphics();
               var9.setColor(var4);
               var9.fillRect(0, 0, 20, 20);
               writeImageAsGif(var8, var6);
            }
         }
      }

   }

   private void makeColorKeyHexStrings() {
      this.mColorKeyHexStrings.removeAllElements();
      int var1 = Math.min(this.mChartItemMax, this.mValues.size());
      var1 = Math.min(var1, sRowColors.size());

      for(int var2 = 0; var2 < var1; ++var2) {
         Color var3 = this.getColorForBar(var2);
         if (var3 != null) {
            String var4 = this.makeColorHexString(var3);
            this.mColorKeyHexStrings.addElement("#" + var4);
         }
      }

   }

   private String makeColorHexString(Color var1) {
      String var2 = Integer.toHexString(var1.getRed());
      String var3 = Integer.toHexString(var1.getGreen());
      String var4 = Integer.toHexString(var1.getBlue());
      if (var2.length() < 2) {
         var2 = "0" + var2;
      }

      if (var3.length() < 2) {
         var3 = "0" + var3;
      }

      if (var4.length() < 2) {
         var4 = "0" + var4;
      }

      return var2 + var3 + var4;
   }

   private void makeChart() {
      try {
         int var1 = 0;
         int var2 = Integer.MAX_VALUE;
         int var3 = Integer.MIN_VALUE;

         for(int var4 = 0; var4 < this.mChartItemMax && var4 < this.mValues.size(); ++var4) {
            String var5 = (String)this.mValues.elementAt(var4);
            if (var5 != null && var5.length() >= 1) {
               Integer var6 = new Integer(var5);
               int var7 = var6;
               if (var7 < var2) {
                  var2 = var7;
               }

               if (var7 > var3) {
                  var3 = var7;
               }

               var1 += var7;
            }
         }

         if (var2 == Integer.MAX_VALUE) {
            var2 = 0;
         }

         if (var3 == Integer.MIN_VALUE) {
            var3 = 0;
         }

         if (var3 < 1) {
            var2 = 0;
            var3 = 2;
         }

         if (var2 == var3) {
            var2 = (int)Math.ceil((double)var3 * 0.9);
         }

         this.makeImage();
         switch (this.mChartType) {
            case 1:
               this.mAreaShape = "POLYGON";
               this.makePieChart(var1);
               return;
            case 2:
               this.mAreaShape = "RECT";
               this.makeBarChart(var2, var3);
               return;
         }
      } catch (Exception var8) {
         ((Throwable)var8).printStackTrace();
      }

   }

   private void makeImage() {
      this.mImage = this.mImageWin.createImage(this.mChartWidth, this.mChartHeight + this.mAxisHeight);
      if (this.mImage != null) {
         Graphics var1 = this.mImage.getGraphics();
         var1.setColor(Color.white);
         var1.fillRect(0, 0, this.mChartWidth, this.mChartHeight + this.mAxisHeight);
      }
   }

   private void makePieChart(int var1) throws Exception {
      if (var1 == 0) {
         throw new Exception(this.cBadChartError);
      } else {
         Graphics var2 = this.mImage.getGraphics();
         int var3 = 0;

         for(int var4 = 0; var4 < this.mChartItemMax && var4 < this.mValues.size(); ++var4) {
            Color var5 = (Color)sRowColors.elementAt(var4);
            var2.setColor(var5);
            int var6 = this.getValue(this.mValues, var4);
            if (var6 >= 0) {
               int var7 = 360 * var6 / var1;
               if (var4 == this.mChartItemMax - 1 || var4 == this.mValues.size() - 1) {
                  var7 = 360 - var3;
               }

               var2.fillArc(0, 0, 250, 250, var3, var7);
               var3 += var7;
            }
         }

      }
   }

   private void makeBarChart(int var1, int var2) throws Exception {
      Graphics var3 = this.mImage.getGraphics();
      int var4 = this.drawBarChartGrid(var3, var1, var2);
      int var5 = Math.min(this.mChartItemMax, this.mValues.size());
      int var6 = this.mChartWidth - var4 - 10;
      int var7 = var6 / (2 * var5 + 1);
      int var8 = var4 + 10 + var7;
      int var9 = this.mChartHeight - 2;
      this.drawBaseLine(var3, var8, var9, var5, var7);
      if (this.useAxis()) {
         this.drawAxis(var3, var8, var9, var5, var7);
      }

      this.drawBars(var3, var8, var9, var5, var7, var1, var2);
   }

   private int drawBarChartGrid(Graphics var1, int var2, int var3) throws Exception {
      int var4 = this.calcBarFloor(var2, var3);
      int var5 = this.calcBarCeil(var2, var3);
      int var6 = this.calcGridScale(Math.abs(var5 - var4));
      Font var7 = new Font("Ariel", 0, 10);
      FontMetrics var8 = var1.getFontMetrics(var7);
      int var9 = var8.getHeight();
      byte var10 = 0;
      String var11 = this.numericLabelFor(var5);
      int var12 = var8.stringWidth(var11) + 10;
      int var13 = this.mChartHeight - 2 - var9;

      for(int var14 = var4; var14 < var5; ++var14) {
         if (var6 == 0 || var14 % var6 == 0) {
            int var15 = this.calcBarHeight(var14, var2, var3);
            int var16 = 10 + var12;
            int var17 = this.mChartHeight - 2 - var15;
            var11 = this.numericLabelFor(var14);
            int var18 = var16 - var8.stringWidth(var11) - 10;
            int var19 = var17 + var9 / 2 - 1;
            if (var19 < var13 && var19 > var9) {
               var13 = var19 - var9 - var10;
               var1.setColor(Color.black);
               var1.drawString(var11, var18, var19);
               var1.setColor(Color.lightGray);
               var1.drawLine(var16, var17, this.mChartWidth - 10, var17);
            }
         }
      }

      return var12;
   }

   private void drawBaseLine(Graphics var1, int var2, int var3, int var4, int var5) {
      int var6 = var2 + var4 * var5 * 2;
      var6 = Math.min(var6, this.mChartWidth - 10);
      var1.setColor(Color.black);
      var1.drawLine(var2 - var5, var3, var6, var3);
      var1.drawLine(var2 - var5, var3 + 1, var6, var3 + 1);
   }

   private void drawAxis(Graphics var1, int var2, int var3, int var4, int var5) {
      int var6 = var2 + var5 / 2;
      int var7 = var3 + this.mAxisHeight / 2;
      Font var8 = new Font("Ariel", 0, 9);
      var1.setFont(var8);
      FontMetrics var9 = var1.getFontMetrics(var8);
      int var10 = var9.getHeight() / 2;
      var1.setColor(Color.black);

      for(int var11 = 0; var11 < var4; ++var11) {
         String var12 = (String)this.mLabels.elementAt(var11);
         if (var12 != null && var12.length() >= 1) {
            int var13 = Math.min(this.mAxisWidth, var12.length());

            for(int var14 = 0; var14 < var13; ++var14) {
               char var15 = var12.charAt(var14);
               if (this.mAxisDelims.indexOf(var15) != -1) {
                  var13 = var14;
               }
            }

            if (var13 >= 1) {
               var12 = var12.substring(0, var13);
               int var17 = var9.stringWidth(var12) / 2;
               var1.drawString(var12, var6 - var17, var7 - var10);
               var6 += var5 * 2;
            }
         }
      }

   }

   private void drawBars(Graphics var1, int var2, int var3, int var4, int var5, int var6, int var7) {
      int var8 = var2;

      for(int var10 = 0; var10 < var4; ++var10) {
         Color var9;
         if (var10 < sRowColors.size()) {
            try {
               var9 = this.getColorForBar(var10);
            } catch (Exception var15) {
               var9 = Color.white;
            }
         } else {
            var9 = Color.white;
         }

         int var11 = this.getValue(this.mValues, var10);
         if (var11 > 0) {
            int var12 = this.calcBarHeight(var11, var6, var7);
            int var13 = var3 - var12;
            this.drawBar(var1, var8, var13, var5, var12, var9);
            String var14 = var8 + "," + var13 + "," + (var8 + var5) + "," + (var13 + var12);
            this.mAreaCoords.addElement(var14);
         }

         var8 += var5 * 2;
      }

   }

   private void drawBar(Graphics var1, int var2, int var3, int var4, int var5, Color var6) {
      var1.setColor(Color.black);
      var1.drawRect(var2 - 1, var3 - 1, var4 + 1, var5);
      var1.setColor(var6);
      var1.fillRect(var2, var3, var4, var5);
   }

   private void draw3dRect(Graphics var1, int var2, int var3, int var4, int var5, int var6, Color var7) {
      var1.setColor(Color.lightGray);

      for(int var8 = 0; var8 < var6; ++var8) {
         var1.drawLine(var2 + var6 - var8, var3 + var8, var2 + var4 - (var8 + 1), var3 + var8);
      }

      var1.setColor(var7.darker());

      for(int var9 = 1; var9 <= var6; ++var9) {
         var1.drawLine(var2 + var4 - var9, var3 + var9 - 1, var2 + var4 - var9, var3 + var5 - var6 + var9);
      }

      var1.setColor(var7);
      var1.fillRect(var2, var3 + var6, var4 - var6, var5);
   }

   private int calcBarVertMargin(int var1, int var2) {
      double var3 = (double)Math.abs(var2 - var1);
      double var5 = (double)this.calcOrderOfMag((float)var2);
      double var7 = Math.max((double)10.0F, Math.pow((double)10.0F, var5 - (double)1.0F));
      if (var3 < var7) {
         var3 = var7;
      }

      double var9 = (double)20.0F * var3 / (double)100.0F;
      return (int)Math.round(var9);
   }

   private int calcBarFloor(int var1, int var2) {
      int var3 = this.calcBarVertMargin(var1, var2);
      return Math.max(0, var1 - var3);
   }

   private int calcBarCeil(int var1, int var2) {
      int var3 = this.calcBarVertMargin(var1, var2);
      return var2 + var3;
   }

   private int calcBarHeight(int var1, int var2, int var3) {
      int var4 = this.calcBarFloor(var2, var3);
      float var5 = this.calcPixelsPerValue(var2, var3);
      Float var6 = new Float((float)(var1 - var4) * var5);
      return var6.intValue();
   }

   private float calcPixelsPerValue(int var1, int var2) {
      int var3 = this.calcBarFloor(var1, var2);
      int var4 = this.calcBarCeil(var1, var2);
      int var5 = Math.abs(var4 - var3);
      float var6 = 0.0F;
      if (var5 < 1) {
         var6 = 246.0F;
      } else {
         var6 = 246.0F / (float)var5;
      }

      return var6;
   }

   private int calcGridScale(int var1) throws Exception {
      int var2 = this.calcOrderOfMag((float)var1);
      double var3 = Math.min((double)1.0F, Math.pow((double)10.0F, (double)(var2 - 1)));
      if (var3 == (double)0.0F) {
         throw new Exception(this.cBadChartError);
      } else {
         double var5 = (double)Math.round((double)var1 / var3) * var3;
         double var7 = var5 / (double)10.0F;
         return (int)Math.round(var7);
      }
   }

   private int calcOrderOfMag(float var1) {
      int var2;
      for(var2 = 0; var1 > 1.0F; ++var2) {
         var1 /= 10.0F;
      }

      return var2;
   }

   private String numericLabelFor(int var1) {
      String var2 = Integer.toString(var1);
      int var3 = var2.length();
      if (var3 > 4) {
         String var4 = new String();

         for(int var5 = 0; var5 < var3; ++var5) {
            if (var5 > 0 && var5 % 3 == 0) {
               var4 = "," + var4;
            }

            var4 = var2.charAt(var3 - var5 - 1) + var4;
         }

         var2 = var4;
      }

      return var2;
   }

   private int getValue(Vector var1, int var2) {
      String var3 = (String)var1.elementAt(var2);
      if (var3 == null) {
         return -1;
      } else {
         Integer var4 = new Integer(var3);
         return var4;
      }
   }

   public boolean isValid() {
      return this.mImage != null;
   }

   public static int getColorForRow(int var0) {
      int var1 = 1;

      try {
         var1 = (Integer)sRowColors.elementAt(var0);
      } catch (Exception var2) {
         var1 = 1;
      }

      return var1;
   }

   public Color getColorForBar(int var1) {
      return var1 < sBarColors.size() ? (Color)sBarColors.elementAt(var1) : Color.white;
   }

   public void cleanUp() {
      this.mImageWin.dispose();
      this.mImageWin = null;
   }

   static {
      sRowColors.addElement(new Integer(2));
      sRowColors.addElement(new Integer(4));
      sRowColors.addElement(new Integer(3));
      sRowColors.addElement(new Integer(7));
      sRowColors.addElement(new Integer(14));
      sRowColors.addElement(new Integer(5));
      sRowColors.addElement(new Integer(6));
      sRowColors.addElement(new Integer(8));
      sRowColors.addElement(new Integer(10));
      sRowColors.addElement(new Integer(0));
      sBarColors = new Vector();
      sBarColors.addElement(Color.red);
      sBarColors.addElement(Color.blue);
      sBarColors.addElement(Color.green);
      sBarColors.addElement(Color.cyan);
      sBarColors.addElement(Color.gray);
      sBarColors.addElement(Color.magenta);
      sBarColors.addElement(Color.yellow);
      sBarColors.addElement(Color.red.darker());
      sBarColors.addElement(Color.blue.darker());
      sBarColors.addElement(Color.black);
   }
}
