package lotus.notes.apps.reports;

import lotus.domino.Database;
import lotus.domino.DateTime;
import lotus.domino.Document;
import lotus.domino.NotesException;

public class RepQuery {
   private static final int MAX_RESPONSES = 25;
   private static final int SECONDS_IN_DAY = 86400;
   private static final String WILDCARD = new String("*");
   public static String sReportTypeField = "ReportType";
   public static String sTimeRangeField = "TimeRange";
   public static String sReportChartField = "ReportChart";
   public static String sReportTableField = "ReportTable";
   public static String sUseSenderNameField = "UseSenderName";
   public static String sQualifySenderNameField = "QualifySenderName";
   public static String sSenderNameTextField = "SenderNameText";
   public static String sUseRecipNameField = "UseRecipName";
   public static String sQualifyRecipNameField = "QualifyRecipName";
   public static String sRecipNameTextField = "RecipNameText";
   public static String sUseDeliveryStatusField = "UseDeliveryStatus";
   public static String sQualifyDeliveryStatusField = "QualifyDeliveryStatus";
   public static String sDeliveryStatusField = "DeliveryStatus";
   public static String sUseMessageSizeField = "UseMessageSize";
   public static String sQualifyMessageSizeField = "QualifyMessageSize";
   public static String sMessageSize = "MessageSize";
   public static String sToday = "T";
   public static String sYesterday = "Y";
   public static String sOverTheLastWeek = "LW";
   public static String sOverTheLastTwoWeeks = "L2W";
   public static String sOverTheLastMonth = "LM";
   public static String sAllInfo = "ALL";
   public static String sContains = "C";
   public static String sExactlyMatches = "EM";
   public static String sIs = "IS";
   public static String sIsNot = "NOT";
   public static String sDelivered = "D";
   public static String sNotDelivered = "ND";
   public static String sBeingProcessed = "BP";
   public static String sIsGreaterThan = "GT";
   public static String sIsLessThan = "LT";
   private Document mDoc;
   private RepAgent mAgent;
   private Database mDb;
   private Integer mReportId;
   private String mEarliestArrivalTime;
   private String mLatestArrivalTime;
   private String mInboundOriginator;
   private String mOutboundRecipient;
   private Integer mDispositionStatus;
   private Integer mMinMsgSize;
   private Integer mMaxMsgSize;
   private int mMaxResponses;

   public Integer getReportId() {
      return this.mReportId;
   }

   public String getEarliestArrivalTime() {
      return this.mEarliestArrivalTime;
   }

   public String getLatestArrivalTime() {
      return this.mLatestArrivalTime;
   }

   public String getInboundOriginator() {
      return this.mInboundOriginator;
   }

   public String getOutboundRecipient() {
      return this.mOutboundRecipient;
   }

   public Integer getDispositionStatus() {
      return this.mDispositionStatus;
   }

   public Integer getMinMsgSize() {
      return this.mMinMsgSize;
   }

   public Integer getMaxMsgSize() {
      return this.mMaxMsgSize;
   }

   public int getMaxResponses() {
      return this.mMaxResponses;
   }

   public void setMaxResponses(int var1) {
      this.mMaxResponses = var1;
   }

   public RepQuery(RepAgent var1, Document var2, Database var3) {
      this.mDoc = var2;
      this.mAgent = var1;
      this.mDb = var3;

      try {
         this.setReportId();
         this.setTimeRange();
         this.setSenderName();
         this.setRecipName();
         this.setDeliveryStatus();
         this.setMessageSize();
      } catch (Exception var5) {
         ((Throwable)var5).printStackTrace();
      }
   }

   void reopenDoc() {
      try {
         String var1 = this.mDoc.getNoteID();
         this.mDoc.recycle();
         this.mDoc = null;
         this.mDoc = this.mDb.getDocumentByID(var1);
      } catch (Exception var2) {
         ((Throwable)var2).printStackTrace();
      }
   }

   protected boolean isChecked(Document var1, String var2) {
      boolean var3 = false;

      try {
         String var4 = var1.getItemValueString(var2);
         if (var4 != null) {
            var3 = true;
         }
      } catch (Exception var5) {
         ((Throwable)var5).printStackTrace();
      }

      return var3;
   }

   protected boolean equalsValue(Document var1, String var2, String var3) {
      boolean var4 = false;

      try {
         String var5 = var1.getItemValueString(var2);
         if (var5 == null) {
            return false;
         }

         if (var5.equals(var3)) {
            var4 = true;
         }
      } catch (Exception var6) {
         ((Throwable)var6).printStackTrace();
      }

      return var4;
   }

   public void setReportId() {
      try {
         String var1 = this.mDoc.getItemValueString(sReportTypeField);
         if (var1 != null) {
            this.mReportId = Integer.valueOf(var1);
         } else {
            this.mReportId = null;
         }
      } catch (Exception var2) {
         this.mReportId = null;
      }
   }

   private void setTimeRange() {
      try {
         String var1 = this.mDoc.getItemValueString(sTimeRangeField);
         DateTime var2 = this.mAgent.mSession.createDateTime("");
         var2.setNow();
         this.mLatestArrivalTime = var2.toString();
         if (var1 != null) {
            if (var1.equals(sAllInfo)) {
               if (this.mReportId == 11) {
                  this.setMaxResponses(-1);
               }

            } else {
               DateTime var3 = this.mAgent.mSession.createDateTime("");
               var3.setLocalTime("Today");
               var3.setLocalTime(var3.toString() + " 00:00:00 AM");
               if (var1.equals(sYesterday)) {
                  var3.adjustDay(-1, true);
               }

               if (var1.equals(sOverTheLastWeek)) {
                  var3.adjustDay(-7, true);
               }

               if (var1.equals(sOverTheLastTwoWeeks)) {
                  var3.adjustDay(-14, true);
               }

               if (var1.equals(sOverTheLastMonth)) {
                  var3.adjustMonth(-1, true);
               }

               this.mEarliestArrivalTime = var3.toString();
               this.calculateMaxResponses(var3, var2);
            }
         }
      } catch (Exception var4) {
         ((Throwable)var4).printStackTrace();
      }
   }

   private void calculateMaxResponses(DateTime var1, DateTime var2) {
      int var3 = 25;
      if (this.getReportId() == 11) {
         int var4 = 0;

         try {
            var4 = var2.timeDifference(var1);
         } catch (NotesException var6) {
         }

         if (var4 > 86400) {
            int var5 = (int)Math.ceil((double)((float)var4 / 86400.0F));
            if (var5 > 25) {
               var3 = var5;
            }
         }
      }

      this.setMaxResponses(var3);
   }

   private void setSenderName() {
      try {
         if (this.isChecked(this.mDoc, sUseSenderNameField)) {
            String var1 = this.mDoc.getItemValueString(sSenderNameTextField);
            if (this.equalsValue(this.mDoc, sQualifySenderNameField, sContains)) {
               var1 = WILDCARD + var1 + WILDCARD;
            }

            this.mInboundOriginator = var1;
            return;
         }
      } catch (Exception var2) {
         ((Throwable)var2).printStackTrace();
      }

   }

   private void setRecipName() {
      try {
         if (this.isChecked(this.mDoc, sUseRecipNameField)) {
            String var1 = this.mDoc.getItemValueString(sRecipNameTextField);
            if (this.equalsValue(this.mDoc, sQualifyRecipNameField, sContains)) {
               var1 = WILDCARD + var1 + WILDCARD;
            }

            this.mOutboundRecipient = var1;
            return;
         }
      } catch (Exception var2) {
         ((Throwable)var2).printStackTrace();
      }

   }

   private void setDeliveryStatus() {
      try {
         if (this.isChecked(this.mDoc, sUseDeliveryStatusField)) {
            int var1 = 1;
            boolean var2 = this.equalsValue(this.mDoc, sQualifyDeliveryStatusField, sIs);
            if (this.equalsValue(this.mDoc, sDeliveryStatusField, sDelivered)) {
               var1 = var2 ? 84 : 43;
            } else if (this.equalsValue(this.mDoc, sDeliveryStatusField, sNotDelivered)) {
               var1 = var2 ? 41 : 86;
            } else if (this.equalsValue(this.mDoc, sDeliveryStatusField, sBeingProcessed)) {
               var1 = var2 ? 2 : 125;
            }

            this.mDispositionStatus = new Integer(var1);
         } else {
            this.mDispositionStatus = new Integer(127);
         }
      } catch (Exception var3) {
         this.mDispositionStatus = null;
         ((Throwable)var3).printStackTrace();
      }
   }

   private void setMessageSize() {
      try {
         if (this.isChecked(this.mDoc, sUseMessageSizeField)) {
            boolean var1 = this.equalsValue(this.mDoc, sQualifyMessageSizeField, sIsGreaterThan);
            int var2 = this.mDoc.getItemValueInteger(sMessageSize);
            if (var1) {
               this.mMinMsgSize = new Integer(var2);
               return;
            }

            this.mMaxMsgSize = new Integer(var2);
            return;
         }
      } catch (Exception var3) {
         this.mMinMsgSize = null;
         this.mMaxMsgSize = null;
         ((Throwable)var3).printStackTrace();
      }

   }

   public void dump() {
      try {
         System.out.println();
         System.out.println("QUERY From Document: " + this.mDoc.getNoteID());
         System.out.println(">> ReportId = " + this.getReportId());
         System.out.println(">> EarliestArrivalTime = " + this.getEarliestArrivalTime());
         System.out.println(">> LatestArrivalTime = " + this.getLatestArrivalTime());
         System.out.println(">> InboundOriginator = " + this.getInboundOriginator());
         System.out.println(">> OutboundRecipient = " + this.getOutboundRecipient());
         System.out.println(">> DispositionStatus = " + this.getDispositionStatus());
         System.out.println(">> MinMsgSize = " + this.getMinMsgSize());
         System.out.println(">> MaxMsgSize = " + this.getMaxMsgSize());
      } catch (Exception var2) {
         ((Throwable)var2).printStackTrace();
      }
   }

   public String toString() {
      String var1 = new String();
      String var2 = ",";
      String var3 = "\"";
      var1 = var1 + var3 + this.stripNull(this.getReportId()) + var3 + var2;
      var1 = var1 + var3 + this.stripNull(this.getEarliestArrivalTime()) + var3 + var2;
      var1 = var1 + var3 + this.stripNull(this.getLatestArrivalTime()) + var3 + var2;
      var1 = var1 + var3 + this.stripNull(this.getInboundOriginator()) + var3 + var2;
      var1 = var1 + var3 + this.stripNull(this.getOutboundRecipient()) + var3 + var2;
      var1 = var1 + var3 + this.stripNull(this.getDispositionStatus()) + var3 + var2;
      var1 = var1 + var3 + this.stripNull(this.getMinMsgSize()) + var3 + var2;
      var1 = var1 + var3 + this.stripNull(this.getMaxMsgSize()) + var3 + var2;
      if (this.getMaxResponses() != 0) {
         var1 = var1 + var3 + this.stripNull(new Integer(this.getMaxResponses())) + var3;
      } else {
         var1 = var1 + var3 + "" + var3;
      }

      return var1;
   }

   public String stripNull(String var1) {
      return var1 != null && var1 != "null" ? var1 : "";
   }

   public String stripNull(Integer var1) {
      return var1 == null ? "" : var1.toString();
   }
}
