package lotus.notes.apps.wmsgtrc;

import java.io.PrintWriter;
import java.util.Vector;
import lotus.domino.DateTime;
import lotus.domino.Document;
import lotus.domino.NotesException;
import lotus.domino.Session;
import lotus.notes.addins.ispy.NABUtils;

public class MsgTrackRequestEntry {
   private static final int SERVER_RECORD = 0;
   private static final int PERSON_RECORD = 1;
   public static final String WILDCARD = new String("*");
   private InternationalResources intlStr = new InternationalResources("lotus.notes.apps.wmsgtrc.WebMsgTrackResources");
   private boolean WMSGTRACK_DEBUG = false;
   private static String sOriginator = "InboundOriginator";
   private static String sRecipient = "InboundRecipient";
   private static String sWhen = "When";
   private static String sMta = "MTA";
   private static String sSubject = "MsgSubject";
   private static String sOutHtml = "HtmlOut";
   private static String sDeliveryStatusField = "DispositionStatus";
   private static String sMinMsgSize = "MinMsgSize";
   private static String sMaxMsgSize = "MaxMsgSize";
   private static String sUniqueMsgID = "UniqueMsgID";
   private static String sTimeZone = "LocalTimeZone";
   public static String sToday = "Today";
   public static String sYesterday = "Yesterday";
   public static String sOverTheLastWeek = "Over the last week";
   public static String sOverTheLastTwoWeeks = "Over the last two weeks";
   public static String sOverTheLastMonth = "Over the last month";
   public static String sAllInfo = "As long as information is available";
   public static String sSenderServer = "Sender's Server";
   private Document mDoc;
   private Session mSession;
   private PrintWriter mpw;
   private String docID;
   private DateTime earliestArrivalTime;
   private DateTime latestArrivalTime;
   private DateTime aStartDT;
   private DateTime aEndDT;
   private String inboundOriginator;
   private String inboundRecipient;
   private String mta;
   private String uniqueMsgID;
   private String subject;
   private DispositionStatus dispositionStatus;
   private int minMsgSize;
   private int maxMsgSize;
   private DateTime gmtTime;
   private boolean dst = false;
   private int timeZone;

   public String getMsgUniqueMsgID() {
      return this.uniqueMsgID;
   }

   public String getInboundOriginator() {
      return this.inboundOriginator;
   }

   public String getInboundRecipient() {
      return this.inboundRecipient;
   }

   public String getSubject() {
      return this.subject;
   }

   public String getMta() {
      return this.mta;
   }

   public String getDocID() {
      return this.docID;
   }

   public int getDispositionStatus() {
      return this.dispositionStatus.getIntValue();
   }

   public String getDispositionStatusString() {
      return DispositionStatus.stringValue(this.dispositionStatus.getIntValue());
   }

   public int getMinMsgSize() {
      return this.minMsgSize;
   }

   public int getMaxMsgSize() {
      return this.maxMsgSize;
   }

   public DateTime getEarliestArrivalTime() {
      return this.earliestArrivalTime;
   }

   public DateTime getLatestArrivalTime() {
      return this.latestArrivalTime;
   }

   public int getDST() {
      return this.dst ? 1 : 0;
   }

   public boolean getDSTbool() {
      return this.dst;
   }

   public long getTimeZone() {
      Integer var1 = new Integer(this.timeZone);
      return var1.longValue();
   }

   public MsgTrackRequestEntry(Session var1) {
      this.mSession = var1;
   }

   public MsgTrackRequestEntry(Document var1, Session var2) {
      this.mDoc = var1;
      this.mSession = var2;

      try {
         this.WMSGTRACK_DEBUG = this.checkDebug(var2);
         String var3 = this.mDoc.getItemValueString(sOriginator);
         if (var3 != null) {
            this.setSenderName(var3);
         }

         String var4 = this.mDoc.getItemValueString(sRecipient);
         if (var4 != null) {
            this.setRecipName(var4);
         }

         String var5 = this.mDoc.getItemValueString(sWhen);
         this.setTimeRange(var5);
         String var6 = this.mDoc.getItemValueString(sMta);
         if (!this.setMta(var6)) {
            System.out.println(this.intlStr.getString("err_sender_server") + " " + this.getInboundOriginator());
         }

         String var7 = this.mDoc.getItemValueString(sSubject);
         if (var7 != null) {
            this.setSubject(var7);
         }

         String var8 = this.mDoc.getItemValueString(sUniqueMsgID);
         this.setUniqueMsgID(var8);
         Vector var9 = this.mDoc.getItemValue("LocalTimeZone");
         DateTime var10 = (DateTime)var9.firstElement();
         this.setTimeZone(var10);
         this.setDST(var10);
      } catch (NotesException var11) {
         ((Throwable)var11).printStackTrace();
      }
   }

   public boolean equalsValue(Document var1, String var2, String var3) {
      boolean var4 = false;

      try {
         String var5 = var1.getItemValueString(var2);
         if (var5 == null) {
            return false;
         }

         if (var5.equals(var3)) {
            var4 = true;
         }
      } catch (Exception var6) {
         ((Throwable)var6).printStackTrace();
      }

      return var4;
   }

   public void setTimeRange(String var1) {
      try {
         if (!var1.equals(sAllInfo)) {
            DateTime var2 = this.mSession.createDateTime("");
            DateTime var3 = this.mSession.createDateTime("");
            var2.setLocalTime("Today");
            var2.setLocalTime(var2.toString() + " 00:00:00 AM");
            var3.setNow();
            if (var1.equals(sYesterday)) {
               var2.adjustDay(-1, true);
            }

            if (var1.equals(sOverTheLastWeek)) {
               var2.adjustDay(-7, true);
            }

            if (var1.equals(sOverTheLastTwoWeeks)) {
               var2.adjustDay(-14, true);
            }

            if (var1.equals(sOverTheLastMonth)) {
               var2.adjustMonth(-1, true);
            }

            this.earliestArrivalTime = var2;
            this.latestArrivalTime = var3;
         }
      } catch (NotesException var4) {
         System.out.println(((Throwable)var4).toString());
         ((Throwable)var4).printStackTrace();
      }
   }

   public void setTimeZone(DateTime var1) {
      try {
         this.timeZone = var1.getTimeZone();
      } catch (NotesException var3) {
         ((Throwable)var3).printStackTrace();
      }
   }

   public void setTimeZone(int var1) {
      this.timeZone = var1;
   }

   public void setDST(DateTime var1) {
      try {
         this.dst = var1.isDST();
      } catch (NotesException var3) {
         ((Throwable)var3).printStackTrace();
      }
   }

   public void setDST(int var1) {
      this.dst = var1 != 0;
   }

   public void setTimeRange(DateTime var1, DateTime var2) {
      try {
         this.earliestArrivalTime = var1;
         this.latestArrivalTime = var2;
      } catch (Exception var4) {
         ((Throwable)var4).printStackTrace();
      }
   }

   public void setSenderName(String var1) {
      try {
         this.inboundOriginator = var1 + WILDCARD;
      } catch (Exception var3) {
         ((Throwable)var3).printStackTrace();
      }
   }

   public void setRecipName(String var1) {
      try {
         this.inboundRecipient = var1 + WILDCARD;
      } catch (Exception var3) {
         ((Throwable)var3).printStackTrace();
      }
   }

   public void setUniqueMsgID(String var1) {
      try {
         this.uniqueMsgID = var1;
      } catch (Exception var3) {
         ((Throwable)var3).printStackTrace();
      }
   }

   public void setSubject(String var1) {
      try {
         this.subject = WILDCARD + var1 + WILDCARD;
      } catch (Exception var3) {
         ((Throwable)var3).printStackTrace();
      }
   }

   public boolean setMta(String var1) {
      boolean var2 = false;

      try {
         if (var1 == null) {
            return var2;
         }

         if (var1.equals(sSenderServer)) {
            String var3 = this.getInboundOriginator().substring(0, this.getInboundOriginator().indexOf(WILDCARD));
            if (this.WMSGTRACK_DEBUG) {
               System.out.println("OriginatorName =" + var3);
            }

            if (var3 == null) {
               return var2;
            }

            Document var4 = NABUtils.getFirstDocumentFromAddressBook(this.mSession, 1, var3);
            if (var4 != null) {
               var1 = var4.getItemValueString("MailServer");
               if (var1 != null) {
                  this.mta = var1;
                  if (this.WMSGTRACK_DEBUG) {
                     System.out.println("Mail server = " + this.mta);
                  }

                  var2 = true;
               }
            } else {
               System.out.println(this.intlStr.getString("no_adr_record") + " " + var3);
            }

            Object var7 = null;
         } else {
            this.mta = var1;
            var2 = true;
         }
      } catch (Exception var5) {
         ((Throwable)var5).printStackTrace();
      }

      return var2;
   }

   public void setDeliveryStatus(int var1) {
      this.dispositionStatus = new DispositionStatus(var1);
   }

   public void setMessageSize(int var1, int var2) {
      try {
         this.minMsgSize = 0;
         this.maxMsgSize = 0;
         if (var1 < this.minMsgSize) {
            var1 = this.minMsgSize;
         }

         if (var2 <= var1) {
            var2 = var1;
         }

         this.minMsgSize = var1 * 1024;
         this.maxMsgSize = var2 * 1024;
      } catch (Exception var4) {
         ((Throwable)var4).printStackTrace();
      }
   }

   public void dump(PrintWriter var1, Document var2) {
      try {
         System.out.println("MtRequest Entry Values");
         System.out.println(" QUERY From Document with UNID: " + var2.getUniversalID());
         System.out.println(" InboundOriginator = " + this.getInboundOriginator());
         System.out.println(" InboundRecipient = " + this.getInboundRecipient());
         System.out.println(" Subject = " + this.getSubject());
         System.out.println(" Mta = " + this.getMta());
         System.out.println(" TimeZone = " + this.getTimeZone());
         System.out.println(" DaylightSavings = " + this.getDST());
         DateTime var3 = this.getEarliestArrivalTime();
         if (var3 == null) {
            System.out.println("EarliestArrivalTime = null");
         } else {
            System.out.println(" EarliestArrivalTime = " + var3.getLocalTime());
         }

         DateTime var4 = this.getLatestArrivalTime();
         if (var4 == null) {
            System.out.println("LatestArrivalTime = null");
         } else {
            System.out.println(" LatestArrivalTime = " + var4.getLocalTime());
         }

         System.out.println("");
      } catch (Exception var5) {
         ((Throwable)var5).printStackTrace();
      }
   }

   private boolean checkDebug(Session var1) {
      boolean var2 = false;

      try {
         String var3 = var1.getEnvironmentString("debug_wmsgtrc", true);
         if (var3 != null && var3.compareTo("1") == 0) {
            var2 = true;
         }
      } catch (NotesException var4) {
      }

      return var2;
   }
}
