package lotus.notes.internal;

import java.lang.reflect.Modifier;
import java.util.Enumeration;
import lotus.notes.JavaString;

class InfoPaneMethodSubItem implements InfoPaneItem {
   private InfoPaneVector vector;
   private String name;

   InfoPaneMethodSubItem(String var1) {
      this.name = JavaString.resource.getString(var1);
      this.vector = new InfoPaneVector();
   }

   InfoPaneMethodSubItem(int var1, boolean var2) throws InfoPaneException {
      this("InfoPane_Method_Modifiers");
      if (!var2 && Modifier.isAbstract(var1)) {
         this.AddMember("abstract");
      }

      if (Modifier.isFinal(var1)) {
         this.AddMember("final");
      }

      if (Modifier.isNative(var1)) {
         this.AddMember("native");
      }

      if (Modifier.isSynchronized(var1)) {
         this.AddMember("synchronized");
      }

   }

   InfoPaneMethodSubItem(Class[] var1) throws InfoPaneException {
      this("InfoPane_Throws");

      try {
         for(int var2 = 0; var1[var2] != null; ++var2) {
            Class var3 = var1[var2];
            if (Modifier.isPublic(var3.getModifiers())) {
               this.AddMember(var3.getName(), var3.toString());
            }
         }

      } catch (ArrayIndexOutOfBoundsException var4) {
      }
   }

   InfoPaneMethodSubItem(Class var1) throws InfoPaneException {
      this("InfoPane_Return_Type");

      String var2;
      for(var2 = ""; var1.isArray(); var2 = var2 + "[]") {
         var1 = var1.getComponentType();
      }

      this.AddMember(var1.getName() + var2, var1.toString() + var2);
   }

   InfoPaneMemberItem AddMember(String var1) throws InfoPaneException {
      return (InfoPaneMemberItem)this.vector.Insert(new InfoPaneMemberItem(var1));
   }

   InfoPaneMemberItem AddMember(String var1, String var2) throws InfoPaneException {
      return (InfoPaneMemberItem)this.vector.Insert(new InfoPaneMemberItem(var1, var2));
   }

   InfoPaneMemberItem FindMember(String var1) {
      return (InfoPaneMemberItem)this.vector.Find(var1);
   }

   public boolean HasSubCategory() {
      return this.vector != null && this.vector.size() > 0;
   }

   public Enumeration GetEnumeration() {
      return this.vector == null ? null : this.vector.elements();
   }

   public String GetName() {
      return this.name;
   }

   public String GetLongName() {
      return this.name;
   }

   public boolean HasLongName() {
      return false;
   }

   public boolean CanPaste() {
      return false;
   }

   public void Print(String var1, boolean var2) {
      if (var2 && this.HasLongName() && this.CanPaste()) {
         System.out.println(var1 + this.GetLongName());
      } else {
         System.out.println(var1 + this.GetName());
      }

      if (this.HasSubCategory()) {
         Enumeration var3 = this.GetEnumeration();

         while(var3.hasMoreElements()) {
            ((InfoPaneItem)var3.nextElement()).Print(var1 + "  ", var2);
         }
      }

   }
}
